
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
IBAN module of the Python Fintech package.

This module defines functions to check and create IBANs.
"""

__all__ = ['check_iban', 'create_iban', 'check_bic', 'get_bic', 'parse_iban', 'get_bankname']

def check_iban(iban, bic=None, country=None, sepa=False):
    """
    Checks an IBAN for validity.

    If the *kontocheck* package is available, for German IBANs the
    bank code and the checksum of the account number are checked as
    well.

    :param iban: The IBAN to be checked.
    :param bic: If given, IBAN and BIC are checked in the
        context of each other.
    :param country: If given, the IBAN is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param sepa: If *sepa* evaluates to ``True``, the IBAN is
        checked to be valid in the Single Euro Payments Area.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    ...


def create_iban(bankcode, account, bic=False):
    """
    Creates an IBAN from a German bank code and account number.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.

    :param bankcode: The German bank code.
    :param account: The account number.
    :param bic: Flag if the corresponding BIC should be returned as well.
    :returns: Either the IBAN or a 2-tuple in the form of (IBAN, BIC).
    """
    ...


def check_bic(bic, country=None, scl=False):
    """
    Checks a BIC for validity.

    :param bic: The BIC to be checked.
    :param country: If given, the BIC is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param scl: If set to ``True``, the BIC is checked for occurrence
        in the SEPA Clearing Directory, published by the German Central
        Bank. If set to a value of *SCT*, *SDD*, *COR1*, or *B2B*, *SCC*,
        the BIC is also checked to be valid for this payment order type.
        The *kontocheck* package is required for this option.
        Otherwise a *RuntimeError* is raised.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    ...


def get_bic(iban):
    """
    Returns the corresponding BIC for a given German IBAN.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    ...


def parse_iban(iban):
    """
    Splits a given IBAN into its fragments.

    Returns a 4-tuple in the form of
    (COUNTRY, CHECKSUM, BANK_CODE, ACCOUNT_NUMBER)
    """
    ...


def get_bankname(iban_or_bic):
    """
    Returns the bank name of a given German IBAN or European BIC.
    In the latter case the bank name is read from the SEPA Clearing
    Directory published by the German Central Bank.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x0b\x00\x00\x00@\x00\x00\x00s0\x00\x00\x00y\x08e\x00\x01\x00W\x00n\x14\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01Y\x00n\x02X\x00e\x00e\x02e\x03d\x01'
        b'd\x02\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadeds\xde*\x00\x00PYARMOR\x00\x00\x03\x06\x003\r\r\n\t4\xe0'
        b'\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\x9e*\x00\x00\x00\x00\x00\x00Xi\xe3\x0bs\xe4\x821\x8fw\xb4\xae\x18[7*\x00\x00\x00\x00\x00\x00\x00\x00\xe7\xfc\xe5\xc6c\x91\x87O\xb4\x1dmYg\xed\x90\x02V\xfcC'
        b'\x15Z,F\xdc\xcc~\xc2=\xb0\xf6h\xc5\x19\xe3\xbe0\x1d\xc7!\xcd$\xb2\xfb\xefAULS\xd7!\x831\xaf\x93u\xb5\x9d\x8e\xc0;\r\x9be\xc4>\xd0\n\x04\x1f%"\x94\xb2oQ\xff\x0c\xc5\xa9y\x8b\x93\xbb'
        b'\xc0\xfa\xa5\x19L\xa07\xe9\x98\x8fp\xcc\xe7\x8eU\xcf\xa6\x0f\xd9\x89\xda"A\xd1\x83R\x81\xce\xf4(k\x1dwc\x89\xf5\xc8l\x08[(\x83U\x0bvhx\x9f;\xed\x06\xbe\xe5\xed\xc0\xdf*\x9fz\x86W#\x82x'
        b'\\\xd1\xb3\xa8\xac}\x0e\xab\xaeA\x1f\xc5\xfex\xbeL\xaa\xe7\x91"\xb4]\xe7\x98\x11\xe9\xbbSG8\xaa\xb3\x10rN@\xa9\xae\xc8\x8aO\xc0E\x8b\xa7\xf9Qf2\xa5\xeeCUV\x05)\x96Rs\x92\xf6\x85V\xca'
        b'\xdd\x02*90\xa0\x9b\xcc?\x18\x8e\xcd\xb5\xc2\xde\xcd\xb1\xd5\xf1L\x89H\xecHd\x11\xea\x8c\xa8[\x93\xcd9\x14\xccO\xbfyK\xab\x8c\xba2\x02\xdct\xb5\xba\x0b\xf0\x00\xc3\xd7K\xff\x1f.\x88\x01\x9e\r\x9dZW'
        b'\xdc\xc3\x18\xf4\x87:\xd5\xe68\xbc`\xf9\xb5\xa9hD9\xdb\t\x83w\xc4\xd5\x15RX\xe7\xfdl\xb5\x90\x93:\xe6\x1b\x193\'\xed\xc0\xbcu\xedM{\xb5\x0e\x9b\xfa+t|a\xc9\x1e\xdc"Y\x85\xe0\x90V\xc26'
        b'\xb9\xa1\xe7:\x874\x98\xca\xca\x81=i\xad\xaf\x9b%\x85[\xae)\xea|.\x1d\x9d\xc3\xbe\xc1\xd9\xc3K\xf5\x03\xf1_\xdax\xa7\xdb\xab]\xfbS\x1c\xc9\xdb\xb6\x9f\xe5\x8a\x05B\xc5.\x89\x8b\xdd\xfa\xcbj\xeb\xb8q\x03'
        b'=\xf5\x9f\xde\x07e!\xe5\x99wT\x9bky%/T0\x83\xadr.w\xd2\x00X\xe6.#\x15e<\x8b\xc1\x95.T\xa3\xa8\x94\x9a\xc3\x05t\xb0\xab\x026\xf0\xe3\xc2\xb4\xed\xc17\xfc#\xcb/\x1cP\xed\xe2\xb7'
        b"Bch\xfd\x9f\x19\xe4\xfa\x9f\xaeT&\xcd\x8b\xa2<%\xde'\x10\x9c\xc3\xeb\x8f\x021\xb9\xf2\x06C\x00\xe5\xc8\xf039\x80\xa9\x93:\xe0.\x1a:\xa7\x0c0N\xf4\xafD\xd5\xf0\x9d\xff\xedH\xdbx\x8b\xe5ES\x8d"
        b"t8]!\xf4\x85\r\xf4\x82]\x1e\xa1\xb9\x91\x83'C\xb6nO\x1a\x97C\xd1#b\x1d\x99F\xd4\x9c\x85b\x104M\xa7bK\xa5\x18\xcf\xdc,Qo\x02\x87'r\x8d\xc3\x9f\xeb)k\x7f\xff\xc6\xa4\xde\x14\x8eo"
        b'\xe8\xdc]\xbfm\xad\\L1\x95\xe2f\xf9\xf8\x13^)2=\xaa\x12MC\xef\xcf+!\xbb\x9d\xdc\\\x19\xaf\x971\x02\x05S\xbd|\xd2\xba_yuH71\x1ef\x89\x00q\xff\xe7\xd4\x13\x97\x00~\xba\xbb\xd1j'
        b'\x93\xbe\xc0d\xf4!\xe48\x0eC\r\xbe+T\xf2\x9f~X\xd2\x80q\x0e\xe7\xd7\xac\xca\xb1\xdf\xe1\xca\xa8F\xe4\xf1\xb0\x18\xd4\xcc\xc5eu\x0c\x90\x12\x8br\xf5\x15\xb5\x02\xb6\xde\x7ft\xa9jw\xb0\xbc\xf5\xa1\xfb\xae\xeb'
        b'\xf1\x98\x90\xe2^\xb9\xcc\xf0\xf2\xa4-;\x19\x8b\xd8\xa9\x81\x93$O8<\xf5\x07\x0f\xf9\x0f\x9f\x8fE\xb2\xc7\xa7\x91\xe3\xba\xb0\xeeX\xb0:\xac\xa0GG\x11^\x1fM\x01\x02*w\xf6\xcf\x87\xc6\n`\xfe1\xff\x05\xd6'
        b'\x83d!i\xccj&\x92\x03Q\'\xd3\xc5\x14\xbf`Or\x7f\xce\xf1\xc6\x1b\xb3\xab!\xe9\x15W)\xf9\xe4\xe0\xb3\xc6-[\x97`"\xfcY\x89\x8a0\xff\xb1\xd4)\xdb\x0b5\xfe\xb7A\xa8\x9c~\x04\x06\xd8\xbfJe'
        b"\xfc\xc46\xe1\xf9\x8d\xe2\xe6\x05u\x197\x806\xb3Y\x10\x10\xce\xb9a\x03\xdd\xbfr\x1b'\x87C\x1f\x8b\x04*\xc6\xd0\x94\xebt\x1f\xa7e\xa4\xa9\x83\x817\x87h\x1dA*-\xa4x,|\xa9\xb3\x8cs\x04N||"
        b'\xd4C\xf95\t\xa9\x93\xb9\x9f\xd7\xae\xd0\xefm\x99s`\xa8\xccM\xae\xc2\x0f9\x81\xcdhL\xef\xcaS\xff\x80-\tbF\x96\x98U\xb2 2\\\xc4\xbdV#\x99\xd9Y\xe3\x87/\x1a\xaeH\r\xfeDk\xc6\xa6\x8e'
        b'eb\xccA\x92j`\xc7\x0bE\xf3\xa7s\xe5\x94\xc3Q\xd2$\x9c\xa4?clJ\xec\x0f\x0fW\x95\xac\x8f\xf6\xb3\xea\x9a\xcf\x80J\xf0ip\xde\xaf\xa0\x1dW\xa1\xab{\xe2\x96\xc5\xb7\xc1*0\xda\xe7\x90\x91OQ['
        b'\xacc\xfa\x93(2\xd1aJ:\xaf\xee\x16=\t\xc1\xcd\x87\x88h\x0eym\xfbTA\x8be \xba%\x91\xd43\xd8\x8ay\x16{\r-\x84Yi\xf3k\xeb`\xf8\xb2u\x8d(I\xe8\x1b\xb0\xe0\xa2w\x86\x17\xeb\xb1'
        b'\x1c\xfdU\xc4\xcd\xfc\xa4\xbd\xc6O\xd8H\xe5`3`@\x98\x98?\xdf/\x90\xfe\x84f\x82\x96T\x90\x9a\xd5e\xc1\xa4$$/\xcf\xab\x19\xc2\xfbY\xe8(\xd3~\xb2\xeaJ\xbb\x1f\xe8\xa49\x1e\xc8\x86/g\xe1bx'
        b'N\x8a\xd3\x14+\xfe\xc4\xf8\xc5ct\x11\xf3\x17\xbe\xe5-\xf8[J\x9c\xc0\x9c\xee\xda\xef\xb8\xbf\x036\x83\xa9\xf7h\xe8\x1f\xbf2X\x83\x04\x9e\xa4\xc5:\xde\xda\x84\x88\xbe\xa2\x96\xe8{\xebm5\x9abz\x81\xdc\xd6\x81'
        b'/*\xf2p<\xf6\xbe\xf0w\xea\xa5\x1b\xd8*\xa2n\xa3\x80K\xc1\xa2\xc4(\xe7\x1a*\xb63.8\xa7\xbb\xa6-\x17\xf0:j\x8d\xf8(\x81\xc0\xf7\xc9v\xb1\x0cW\xdeg\xde\xc9S\x14D\xb3\xcdjnW\xa6\xe6\x0c'
        b'\xc0\xe5q\xfe0\xdc\x83\x1bIX\xfc\x83\xfd\xca\xcea\xbb\x07\xf8\xe8\xd9f\xef:\x13\xc8\xd8l\xaa\x0bwe\x0bj{\x81}\xf3\x8d\x18z:\xe7\xc9\xa7\x10x\xca\x92j\xf7\xd0\x1e\x1fGy\xd82R\xf0=\xa4\x87('
        b'(\x9fn\x1f\xe1\xdeY)\xc4\xcc\x0bg\x15\x11D\xd0#\xfa\xd5]7\x1a\xb1\xcdnEY\xbc\x8f9mE\xe9\x83g*I\xc0\x00\xd7>W\x88X\xc5.\xfa\xcf\xb8\x1d)V\x01\xf6BjS\x93\x95\xed\xdde\xc9\xbf'
        b'\xd6\xd4\x1c\xceb\x94*\x16\xd6c\xf8\xf3%\x08q\x9bE\xe4UP}2\xdd\xe8\x1a\x17\x1dY0\x14B\xd1g\xff\xce\xdb\xbf\x1e?\x8a\x8f\xc7\x0f0M\rj\xe5*\xba\xde\xbc\xc22\x1d*\xf0\xfb\xd9Z\xec\x94\xa4\xef'
        b'\x0b\xcc\xc9\xdf\x8d\xffh,M"\x1e\x1a\x1f\xd5f\xa8\x99o-\xfa\xe0\x96R\xcd\xf3\xd0\xa4\xd5\xf1\xc1 \x1cei\x96U\xfaY\xa0\xa2\xf8\xe1\xab\xb4q\x86|\n\xbd\x96\xc6[*\x9f{1\x86J\xda\xd3/\xd6\xc7\xa5'
        b'\xf85\x7f\xbb\xcb\x1e\xf1[G\xedp\xb3\x123c\xd7\x87\x9d\xefsxv$\x80~\x88\xb4I\x8a\x95\xb5-ER\x1cu\x1d\x0f\xcf\t\xbeF\x03\x90\x98\xc4N\r\xe5\x08%)\xbc\xe0\xd9\xe8\xed\t\xa1\rW\xbdt\xb9'
        b'\xf8\xbe\xfa\xfe\x19\x82\xa1\x8a\x87\xd6\x1a]\xc5p\x9f\xff\xf6\xd23\x04\x7f\xd9\xbcH\x92\xad\x18\x81\x91\xd9\x08\x9c;\xb1\xcf54\xa7\xc7[\xa6\xce\x8f6\xfeQ\x0f\xd6\x8d\x04\x19\xd2H\x9fM\xd1+\xf4V\x8a\xd4\xb0\xbd\xfe'
        b'_f:\x16f\xff)\xc5\x9d\x0f\xe5\xe8B\xe7\xca"W\xc7D\xe4E\x95\x04\xb0\xbdPk\x8cU+\x1d\xbc\xf7\xda&>i\\"\xc4\xc8\x13\xb5\xe4\xa3\x9e/\xd7\x915\tDe\xb4\xc77?\xf0z\xde\x7f\x80qy'
        b'g\xe8\x90\xf3\xca\r\xc2|\xab\xbe\x08\xea\x16\x850\x83\x90\x82%\x04\x1c?-\x88\x0e\xd6\xee\x1f\xca\xbfWl\xc9`u}=\xa8\xdc\xbe\xd1q`Y\x98G\xdf\xf7\x0f\x93<\xa2\xc5\xd3 \xc3*r/(\xaeb\xf58'
        b'|\x0bt\xf9\xbe\x03\xc4I\x07\xa8\xc72\x87\xb2\xb62\xf0{(;\xf2](\xea\xd71dF\xf0\x87\xbf\xdf\xd0\xcai\x19\x1c622\x07\x86\xb8\xcf"Yw\x87O\xb9e!PN?\xba\xea8c\xb1c-\xbf\x80'
        b'\xe2\xc4\xb2q@6\x99U[\\\xf6\x0b"\xdbK\xe0\xd9\xf3\t\xeem85\xf7\x8d\xf5r\xca%G\xa1\xed>S\x8b\xe0\xd9\x19M\xbbA\x08\xf1\xc4\xe3 \xf09\x1e\x88|Zz/H\xfd\x87X\x16p`\x89\xd35'
        b'*\x91K\xb7\x02\x9b\x8d\xf5\xa1\xb0;\xad\xf1Pl\xd0\x9a\x8d\xfc\x8b\x12[\x8a\xfa;.\xfag0}\xd1\x0f4\xe9i\xa2\x19.\x99A\xfa\xea\xd3C\xfe\xd7\ta\xee.^9\xd1C\x1f\xb8\x12#\xd1\xa9\x01`U\x92'
        b"\xbe\xfa\x8f'f\xeb v@@\xd4ln\xb6\xaf\x7f\xe7\x02\x1a\x9ck\x13\xe7^q]o,\n\x8e\x98\\\xff\xc4V\x98V\xa6\x82\xfe/1a\x8a\xa5\x87j`\xeb!\xaanJ\x98\t\xf9\x8f3\xf6\xb2WU=\xcf"
        b'*\xbcTl\x10\x83\xfb\x91\xafky\x18\xb8-\x19\xe2\x0ee\xe8FQ\xecm:+\xd73\x11\xaa\x07\xec\xdf/.\xb5\xda\xbb\x98Z\xe7\xc3k\xc3\xa8UM\xce\x82<\x91\xff\x0e\xa8\xac\x19v\xa1\xe8\xea\xaf\xabV\xb6\xac'
        b':\xads\xac\xbe\xce\xd8`\x7f\xfc\\.\\S\x04\x1e\x9d\xe4Uz$\x87\xf3ke\xa2\x01\xd9\xc5\x95\xb2\xd8\x9cZ\xa5\x85\xdb<\x90p\xb8\xf42j\x80\x9e\x06\xc2\xc23\x83\xdc\xdf}\x89\x8f\xf70.\xe4\xb7sr\xf8'
        b'\xbd\xc5\xa90\xab\xcaU:\xe0\xaf\x97!P\x83\xbd\xbd\xfd\x11\x97t\x82\xe75\x1c\xe5\xb9\x01\xb8\xc4w\x02hsy?\xfc\x1c1\x8343\x9b\xbf\xd6\x97\x08\x9d\xbe\xd9\x19\x07WJ\xc0\x7f|FGt+\xc4\xf3O\xcb'
        b'\x92\x9e\xca\xfa\xf6\xa3F\xc8\xa3\x02O#8\n \xaeDJ\xe1\xde\xd1\xd6\xae\xfd[\x06O\xdb\xe4u\xaa#)\xcd&\xe4q\xe3\x88;\xa4\x151\x82\xf1.M\xa0f\xf9\xaa\xc3\xfdD\xb9}\x12\x16\x0e\x84>]\x8f\x0e'
        b'\xf0\xcf\tg\xc19\xa8\x17g\xa4_\x84\x83\x0f\x92\x82\xbc\x06\xbf\xe2\xe5\xb6\xb4\xeb\xb4\x1a\xe19\xa4\xf59\xca\x89\x15\xb5\xdb-\xa2\x0bp\xb8\xc0\xca`)\xf4\xd2j\xd7\xa7.\x97\xc4Md\xad\x17\xd2TU\xedN\xda8'
        b'\xcd\xf6\x88\n?\\\xc2F\xfd\xf1`\x9e\x18\x84\x93U\x05U q\xe2\xb2\xfd\x08\xbaTC\xeaU_\x08\x90\xb1b}\xb3b\xc2\xc7MO\xbd(\xe8\xc5,Y\xac6[v\xb5\x16\xc0 \xfb\x80H\xde\x88=\xfcr\x14'
        b'\x15Z\x14a\xba}.O\xddKl#L\xdc\x7f\x12\x00l\xcc\xf6\xbd\xaf^\xac\xe0\x1a\x05\xfc\x12\x86B\xff\x9b;\xad\x18\x1c^Q\xee)NC\xd4\x9f\xd1u\xacN\t+\xab\x86\xac\xdat\x1e\xd2:\xb6\x95\x94\x8f\n'
        b'\xbf#&\xef\xd2p@\\\xdd\xc7\xd2\x1f\xa3\xa8\xb0\x9ea\t\xfcAQ3\xf9=@\x0f\xb3\x11\xfa\x03\xde\x89<\xf3d9\xb9\x82\x9d\xaa\xa6\xd5(\xd2uL\xbc\xa1\x93\xfd\xd1\xd7g0O\tZ\xba\x13h\x0fW\x9d\x98'
        b'Xi}k\x992\x83\xefN\xa7\xe7bK|\xe1C\x9ev\x14\x17\xe3\xa7\xe7j :\xb4\x11\xf0mH6\x14\xb29z\xaa\x18VN7\x97~\xee\xe9\x9c\xcfu\x89\xfe\xb8\xaf\xc2Q\x7fGP\x8e\x8e\xb9Aa\x8a5'
        b'+O\x91\xa1\xa9\x82\x1an\xd4o\n|\xf0\xdc\xcd\xe3x\xe8\x13^\x99\x81\x1a2_\xe4XF\x95\xcc\xd2\xc9\x8eo\xf2!\xbf\x80\x9cz\xf5\x9e\xb4\x01\xc1a\xa5-\xbc_\xa5\xcb\tn\xff\xe1U\xd9>\x87\x14e?\xf2'
        b'i\xe8\x0f\xbc\x05cJ\x16\xf1\xdc\xec*\xf9\xc4r\xb2\x04a\xb9\xe1h\xe2\xbf\xf8C\xe5\xb4\\U&{\xf7\xe0Z\xc10-\xc4\\W\xe9\x9eq\x85\x00\xc0\xbe\xedG\x18\x96\xf3\x06\x9d\xb8\xf3\xdb\xd1\xc1w\xb5.{\x1c'
        b'\x96"\x91\x90\x0fbK\x91\xeb\x0b\xf2T\'l\x1c\xa1\xda!\xcfOB\xe3\xc6\x10\xb2\x8c\xa6H#\xc7\xcf\xdf=\xcc"!d\xb2\x10\xa4\x8d\xe7\x13Q\xf4\xb5x\xdd\x10\xf2\x17\x86\xb1\xe3\xad\x02\x9e\x90\x82d\xcd\x9b\xf9\xca'
        b'\x0b\xe8\xd0=bhP\x02\x0e4]\x80\xdf\xcc\x1b\x1dY\xf6\x14\xdeB\xca%\x14\x87\x86A\xda\x1d\xcc.\xb6\xb3\x17FE\xa7\x0f\xac\xd9\x8c0\xe6,*,\n\x07r\x1c$\xf6\xb7\x10\xdf\xde\xd1\xde=\x12\x95\x1fRl'
        b'\xdd\xef;E\x89\xa3$\x1bl#s\x05g\xfe\xfdJ\xd4\xff\xdc\xbb\x99\x12QK\xd0\xfd\xa8\xc9\x07E\xdd7]M1Z\xa5\xc3\xcb\x0b{\xb7\xdd\xf7\xe7\xb0\xce\xf8N\x046i\xd9\xfe*\x1d\xd4kN\xdbIhq\x1d'
        b'j\xfe\xd1TA!\xc5\x06\xf7\xb48$\xf6\xa2\xdb\x12\xda\xd8$^\xc7\xbf\x0f\x0e\xec\xf9\x9f\x97>6M\xa9M\xad\x14Zl@\x89\xa1\xd0pxG\xfb\xfaH\xf1\x81\xc1\xba\xca\x05\x99*3im.\xa7\xd4\xe4p\xb7'
        b'`h\x85\x03U\nM\xb4\x97\x953\x0f\xc1\xc7\x88,\xbb\xd1bQ\xc3\x9e\x81\\M|\xa3\xa5\xd4\xb8E\xca\x9c,bw\x9e.#\xd6\x8e/\xcce\x8csD\xa4\x93\xbe\xbex\xa3%:\x192\xae\x95\xa8qG\x7f:'
        b'\xa6\x80\xb1\xac$$\r<\xec\xf6\xfd\xb8\xbe\\\x83\x83\x11\xfd\x90\xf0%\x94\xa2\xeb\x16)\xc7\xae\xc0\x1a5\xbb\xcb\xf6\xf7=~\x16\xc2@\x80\x86\nE\xdf\xacC\x07\xa2<\xf9\xb8s\x14\x05\xab8\xc3\xda\xb8\xec\xcd\xd7\x80'
        b'\x9b\xf0\xca4e\xa0\xbf\xba\xd9,\xf8W\xdc71\xf2\xb3Q$\xc3)1\xa7\xbbk\\q5yC\x1f\x93<\xda8p\x9e\x86b\xbc\x901\x01}\x97@\\h[T\xd0Cb\x81P\xc1@\xe2\x11\xdb\x98,\x8dF'
        b'S\x0b;\xca\xd4\x03\xa7\x05\xa8\x10\xd8\x02\xb4\x0b\xf4\xce\xf9I\x11\xb3\x00?\xaf\xa0\xc8\xe5\xe8\x10*Q\xa4g\xd2.K]\xbf\x83 \x17?\xe9\xc1\xe4\x80<\x1bR\xday\x8c\x84\xf7l\xa8\xaa\x06L\x1bI\x91\x07$\xb3'
        b'q\x9e\xa2\x9aF\xf9VTl\xf3\xa1v\\0\xa7AZ\x1a\xa6\xd6~4\xfb\xf8\x87i\xd3\xd4\xe7H\x93\x80\xc6\x83%x1s\xa9\xf4\x1ax\xa9\xbc\x01!|R(\xeb;\xc4\xfepL\xb5\xe9\xeb\xa8\x96m\xba\x00.'
        b'eu\xd5\xb6\x7fah\x06\xa0\xdb\xa1\x15\x08\xc4AV8\x14\x9b\xd1\x9eW8\xc9\xeb\x98\x97\x86:\xa1\xc5\xd6\xc5\x90:\x98A]\xb0\xc9\x82\x05\xd1~\x13A\xe5\xea\xf9\xaa\x00\x0es\xa7\xabC\xcc\xca\xd2\x93Ux\xa5\xda'
        b'\xa0\xca\xe9\xe9\xa7\xe1\xf9\x06Ri\xed-\x81\xb2\xe4C\xda\x9d\x15\xd4\xce\xff\x8adi\x88Y\x99O\xc9Mt\x1al\x8b\xb2\xa0\xb4\xdc\xc8d\xc8\x05\xe7\xacyaK<\x93\xaf7\x04\xa1\xcd\x7f\xa2\x0e\xec\x8f\xe0\x08q\xea'
        b"\x8a\x99\x8a\xb6\x7f\xdd\xfa`9\x8c\xda\xc3x\xf1\xf0\xfb4\x0f\x03\xb4\x05@0U\x7f9T\xab\xde(\xa4T\x14[\x1ejE\xdd\xfe\x96.^\x03\xeca\x92\xc2\xdc\x12\xf2'cM\x19\x12\x95\t\xe1q\xcf\xe7\xadN;"
        b'i\xa3\xcaQ\xb4\x17H\xbdc&\xb8\xcd[\x95E\xbc\x01\x99\r\x03\xcfYj\x00|\x10\xd8[\x8c\xe2~\xa2\x82;G"\xe5\xc6t^1\\.C\x9c\xf0\xc59%\xfaR\xb2\x03tQA\xdc\xc0\xe9\x1d\xabA\x15\x04'
        b'\x03\xd6\x10*\x1c_\xed\x9d\xe4:\x85\xc3\xb9\xc0\x83P\x0b\xc9\x07\x87N\xa9\x8egI\xbab\xae\xc5\xacJA\xa1\\X\x8c7\x9f(\x0b[\x9e\x15\xf9\x02"\xed.P\x10PB\x02#\x07\x80\xb9q\xd5\x97\x8f\xfe\x80\x00'
        b'S\xe6\xb5\x01Y,a\x99r\xe1+q \x9e\xb5\x13KR\xcc\x94c\x86j#\x97s\x08\xb3\xea\x9e\xeb\xc0\xd5\xb5\xfd1\x85\xd07\x01(\xff\xbe\x9d\x04\xf3\xebnl\xa8r\x9d5\xd7^g\x86x\xbfB\xd0\xe8W|'
        b'L:Wx\xc4\x99\x1f,s\xc6sm\xe0\xb8\xdc` _\xee\xeef\xcb\x1a\xae\xbd_\x0b\xf2k\x00\xec\x05#\xf3U\xbf\x02tX\xb1\xd6m\x92\xd7\x88=\x14)\xdb8\xf6\x11\xcd\x8dC)\xb1\x1dZ\xd2\xb708\x94'
        b'\x1aS.\xa8\x83\x06\xd4\xc4\xe4\x84b&#4\x97B\xc5\x9e\xc2f\x1d\xb2\x00\x99\xa6\x84\xef\xc7$\x8cQ\x98\xad]/A1C\x14\xfe\x07\xdd>@3[\x9c)!\x8f\x904\xa3\xc79\x036P\xe0F\xef\x89R\xd0'
        b'\xfeE01{\xab\x83\xdcB\x1f\x1fk\xf1\x07\xa4\x94\xbc\xd9i\xcb\xc7sER\xb2\x1cq\x06\x0cB\xb2\xf8o\xf0\xb7\x8a\x89\xea\xc9\x88?\x94\xf2g\xd5"\xf0\x93\x8bEr\x92N\x85\xdd\x8e\xea\x91\x11Y\xfc\xaa~\x9a'
        b'\xaf\xed\x0f\xd9O0\xe6\x93A\xdd\x94\xa8Ql\xee\x12\xbdi\xe9\x9b\x04\xc4\xcc)l\x8c\x0bAuB\xf9u\x82p:|q\xe2\x0e\xd3i\xbc\xac\x94N\x84\x85\x83\xc4\xa6\x86\xeb\x11G\x88\xef<\xb4\x99\xf2\xa6MO\x02'
        b"\x8f=N\x1c2\xedt\x177k$\x93\tQ\x08G\xcf\x90\x8ao\x93\xc2{^\x11\xf9\x0f\xf6\xe5\x9f\xd5\x9f\xe2T\x96p\x11\xfcT\xe4\xaa\x99\x80h\x16N\x15'h\xe9\xcb\x10w\xfa\x9a\xa6=\xea\xc23M{$h"
        b'\x8ab\xb8b\xd4w:\xab\xafC~\xbf\x14I\xc4\xee>\xc0\x1a\x00?\xbf\xf2\xf7F5s\xab] \\\x8c\xdb\xa6\xfe\xe8/\xc3\x91P\xb8&\x95V\x91\xff\x02~\xef&\xc1k6N\xda\x8b\xb8\xfa!\xa2\xda\xe1\xeb\x98'
        b'\xa5S\x83"\x19sK`\x91\x02\xefBm\x7f\x0b{s\xbd\xf0\x94R\xf3\xacJ\x17\xcf\x9bu\xa2\\c\xb3\x87\xe9\xf6kc\x95\xfd\x88\x89n7\xff\xac\x01\xdb{[\xcbI\xb5\xd9\xa1b\x93k\x1b\xdd\xb5B\x83c\xb3'
        b'Vq\xe6O\x89\x01\x851\xc6\xfa\xf6k\x1f\x02>\xd2\xbaxx\xe1\x86*(\xd3\xa8j\x1d\x97@i\xcb\x14@lvD\x00\x9b\xb7\xa1_@\x86)\x07\xf4"\xbe?%\x9fO:e;\x92g\x16`XxqQ\xb3'
        b'\xf8\xf4\x88\x8d*\xd1\x8dEH\x93\xd7\x1f\x1e\xedTz\xe8\xae\xd6A]p4\x1aO6 \x1d\xc7)+\xe1\xdc\xf0| zS\xa3\x1a\xb5\xe2\xe15\xe9\x10\xafQ)\xe0?N!}6\x0c/)\xd6\xf6e\xbb\x13\xae'
        b'\x9b\x01\x87\xfe-\x11H\x17\xa1\xbe;\x89x\xca\xae\xfb\xff\xf7\xf6\xcd\x1d\xf5:\x7f\xdbD]J$\x91S\xc7Q\xcb\xe79\xb5i\xb3\xf1\xd7)\xf6\x082\x14\x1a\x08\x18+\x17:k\xf9^:r\xed\x1d\x141\\ \x0b'
        b'\xb8`S\x0641F\xed\x86\x84M5\x9d\x90& f\xe9"\x03\xe6\xd6*W\xb6\xab"mK\xd6\xec\x855\xdf\x86f\x13\x99\xc4\x01\xfea}\x83@_,T\x9e\xea\xfd\xb2\xd0$\xf7*\xe2y\xb2\xb0\x8c\x11r\t'
        b'\xf5TS"yn\x1d.\x05\nX\x08\xc0j\x1e\xc9\xe0\xc8\xdaM\xf7_\x8cXL\xc9\x99\x0eP\x9c^TE\xff\x18\xf6F\x9cO\x8d\x02b\xa3\xceY\x03\xbf\x14\x034\xf5\xfa\x87\x8d(\xcf\xa8\x88@\x06\xde&\x85\xb7'
        b'\xbf\nn\x1bor\x1e\x0b}\x16\xed\xbd\xbbU\x1b\xf0+U,\x955/\xa3"\t\x9f\x81\xdd\xf2{\xdeX\xf8\x0e\x91\x83yN\xb0\xebbM.\x94\xdf6,\x17\xae\xc7:\xbf\x0e\xa7\x8c\x14\x15[\xa0\xb0"\xbe\xcak'
        b'\xeb\xaa\xac\x16):\xd5\x1f\xf2\xe2\xac\xf9,\xbf))\x9f\xbe\xe2\x0b\xeb6I\xb4e\x1b\xbd\x99-\xe1\xaf\xff\x1f\x9d\xd7\xfd\xff>\x0f\xbb\xfcwxn\xc7Q\xfa\xc9\xf7\xcf\x10\x18\x13\xc2\x05i\x9e7\x85Pz\x13\x16u'
        b'\xa2\xa6e2\x05\xf8\x8d\x92\xd9\xe1\r\xf7\xcb\xd5\x98)i\x99P\xe3\xa8\r/\x17\x7f\x13i\xc7?\xb9\xd0n\xbb\xc1R\xb2\x8bA\x91A1\xe5\xacy\xfc\xf2#\xef\x10*\xcd\x8b\x9f\xf9\x97\xa2/\xb6\x89\x829F%\xfd'
        b'\xe4\xb6p-oP}.\xe4\xde\xfe\xc1\x84\x82\x7f7\xc7\x96x^wr\x1cc\xd8"\xbc#M\xe1wv_sZ{S\xff\x17\xc8c\xc3Y\xd8\x9b\x9b\x12\x15\xd7\xcc\xa6R~\x16\xa9\xceg\x82\xba\x9fL\xbb\x92\xef'
        b'\xc0y\x82\xcb^R\xdb\x8f\x02\xa0\xf5\x12\xa7\x10K"]\xa3i\xd0J\xff\xdd>h"\x87\xe5\x14\xf8\x1c\x86^\x13(~\xd2\xbfX\xe0\xeb\x05\xb1\xc7v\x991\x95\xda"@h\x8a#tw\x03b\xa3r\x10,\x8b\xc7'
        b'\xca\xde\x12\xbf\x8be\xea\xfb\x13\x99\xc5-\x1e[3\x1d\xd9\xf6\xf7A^\xd1\x01\x9e\xcd\xa3\n(\xb8oz\x0f\xc4\xb3\xf0\xcf\xc6r[\xb8\x1f\x92\xef5\x18z{\x035\x900\xbb\x14X\x94\x1b91\xc8\x03\x15\xa9\x8d\xbd'
        b'\n6\xb5\xa2\x1e*\x90N\xb3\x9e{?\xc2W\x88\xc1\xb3b>\x99k\x9e t\xe0\xc8\xc8\xc5\xd2\x04\xcc\xfd\x87Y\xee\x9fH,D\xa3\xca\x97\xa1\xda\xb2\x0e$\n\x8dc\xc4f\xffI\rp\xad\x1b\x9dp,\xcd\xb8-'
        b'3\xd3\x07\xd9\x94=\xde\x90\xc8\xc5L(\x94\r\x84C-l\xa2\r\xcb\x05!\xf2\x11\xf53D *\x1b3NI\xa9\xa8\xf9\x99@P\x12G(BM\x81\xa4\xdf\xe3\xa5\x90\xb9 \xd0LS>\xed\x8e\xe5MzUL'
        b'/\x98\x98\x0f\x0b\x89\x83Y\xfb\xac\xae>\x87\x19\x95q\xe7`\xd2\x9e{\xf0X\x192\xf3\xcb^\x8f_\x8f\x94ms+\xb6\xad.\xee#T\x1d\x07\xf0\xd1\xbb\xb2\xe2al\'\x95:\xc7\xd9"\xa2]wS\xd0=\x91Z'
        b"B\xb01\x9e;\x98\x03N\xe5\x9fw9\xba \x0b\x90\xb5Y\x9d\x07\x8d\x1a\x89\xf6D\xbb\xdf*\xa7\xb9>\x02U\xbe\xfe\x843t\x83y\xff'\xcf\x81\xb9S\x9eE\xf0\xa0r\xc5\xfa\xea\x93P:\x82\xa0!\xc9M\x1b\x9a"
        b'7\xcf\x8e\xfd1G\x8a\xe4T\xe5t$\x86\x8f\xeb<\x1f\x16\xfcr\xa8\x15\x02\xb8\xa5\xc3\x7f+\x05L\x04\xd8\x0c_\xbd\x1f/\x8d\xc5|\xafhj\x87%c\x07\xb2\xf6\x99\xf1 \x832\x0b\n\x88\xe3\xb30\x9b\x9c\x07l'
        b"fJ\xde\x11'\xb1\x88\x95#\xafwqt\xdde\x7f\x01Ai\x81\x9dG\x98\xd2\xd8h\xc7\x84g\xc3N\x86u\x7f\xd6]\xef\x19\x08\xce{\x1c\x0c\xd97\x9dS\xef\xad0\xe4d\x9b\xbd\xaa\n\x9e\xe6\x1b\xe2\x19T\x9e\x03"
        b'4`!\xba\x12\x9b\x00\'j\x83\x91o\x97\x8b"\xdb\xcb\x00\x13W\xbf\xdb\x00\xcf61\xc5\xb5\x04#S\xdd\x84X\x98<\x1f\x97\x1c\x1a*\x80/5G\xf4\xcb\xb4\x05\x01\xf0\x9d\xf3\rO\xd3L+=\x11efD\x8a'
        b'\xc1#\xb3\xe1\xf6\xc3\xc1\xc7y\x992Y\xa9\xedF_(\x028\xe5\xe4[\xd2\x17\xca\x7f\xa9\xfb\x80\xe0\x8c\x97\x86\x91\x8c3\xb6\xe5n\xd9`\xd3\x85\x99M\xc6\xd7`\x98\x08\xe0\xfd\xbc\xf0\x7f\xf3\xfd\x14\x987d\x08\xd7\xc9'
        b'\xe3\xe3\x86\xec\'\xaeF\'\xd0\xaf\xfc\x92\x94\x8c\xe9\xb3\xdf=\xcd\x18q\x8c\xc6\x03\xa2\xa2\xdc\xb8R{"\xcar\x8e+\xe3\x0b8sRA\xecus\xa7\xde3\xd8\xc8\x1e\x18u\x06\xc5*\x8f_\xee\x85\x82<\x976\xb1'
        b'\xf3\xa0\xfc\xb0\xe3g\xf1|\x89e\x89\x87I\xf8f\xfba\x863\xd1\x14\xcf\xcehv!\xac(w\xb1\x8d\x98\x1f=\xe9\x03=\xd4\xce\x96\xf3\xbd\xdc\xa7+\xc1(QsTb\xb6\x1dd\x96\x9c&\xfc\x1e[gm\xfeD'
        b'\x0e\\$\n\xc7\xa3i\xf3\xb2\xf7\xf8\x9b\x8cN\x80\xf8\xc6W&Y\xfbx\xe1\xf4\xbd\x0e\x965\xbe\xed \x96\xa6\xa5M\x00WK^r\xdf\x11S\x137\x898\x82\xb39\x99\xc8\x19\xfbQM\x1e\xd12\xb2\xaf\xc1\xe9\x13'
        b"\x1d*\xd9\xe5;\xe9Vb\xb7(8\xa2\xfau\xcf\x8cZ\x0c'\x1b.Ng7t!\x91\x16\x05Wr\x87\xa6\xe1\xda\xe5Z\x88>D\x17\xc9F\xbaq_\xf3\xb9l\xd3\xc8T\xd7l\x0f\xe6\xeb\x06O\xd1\xa1\x1f\x91b"
        b'\x91\x066|\xcc\xb1{\xa7\x93+\x15Gn\xca>\xef\xb2\xef\xb2\x95\xd9\x15\x82\xa8piwk\xafw\xbbN\xf9\xd1\x10\x82b#\x8a\xa2\xe0\xb8\xaa\xf1\xd8\x87\x875\x96\xa1Z$\xf6\xe5T\xf3\xb6-\xed\xa6[\n\xef2'
        b'\xe0\x8aW2)\x01\xd7!\x1a\xf8\xdf]\xd1\xdb\x04\x14\xf8a\xde[c)r\x18-\xbd\xee\x17\xdf $\xc7\xbb\xd9\x9fLx\xec\x0f\x03\x0e%\xb6\xbc\x96\xfa\x19\xa89\xed\xac\xb2W\xdb\xba\xde\x18|\xd6\x917\x86\x88\xb9'
        b'\x115\xc7sf~\x02T\x98!\xc48\xa3d5Q\x1dF6\x13\xd2fh2\xd5\x82DK\x08\xec\x87l\xee\xa2\x90{s8\x96Q\xd5\xe4 \x81Ke\x82\x0c"\xc1\xdd\x85\xddQ\xb5\xb3\xf5\x95\xbdQS2rD'
        b"\x16\xabl\x07jo\x84\xd0\xcc\xf7\xc9\xee\x1701\x9ae\xb2$\x93?\xc6\xbc\xa7\xbb\xa54\xb6\xc5\x8c\xa6'\x86\xb2UFQ\xe9j*)\xef\n\xd7\xdcJ`f|K\x1a\x9a\xb7\xe4\xc7\xd0\xeb!\x95\xbd\x12\xc3+\xe2"
        b'\x1d\xb46?\x0c\x0bk\x0b\xde.L\x9cd\xfdO\x8a\xe4AK\xbe^\xdeo\xe1m?\xf8\xfaf\x87\xb6\x8a\xb9\x16e\xe7\t\x06\xd9\xa2\xd1\xa8B\x04IS\x00\xe2^:\xffK\xf5@\x94\x8aH\x85S\xd8j\xf4\xb1\xfd'
        b"svev\x7f\x1bc-\xa8e\xb1\x13\xcc\\8\x0b\x1f\xe4a\x97(\xf5\x0c6\r\xa9n^R\xddE'\x94\xaa\xc0\xab\xc7\x7f\x1e\x08\xa6\xc4\x8aU\xab\xee\xb5g\xb8\xd3+;\xc11\xe9JJ\xe4\xc7\n\x9dl\xf0\x00"
        b'\xa8A"7t\xb6\x89\xfa~-4\xbba\x82\x0f\x153O\xca\x84\xab\xacQ\xceCM\x0f\x87Z2\xc8!\xc2T\xeb\xa1\xdfk\xf1\x1e\xcfM\x15\xc6\xc5\xe1\xeb\xee\x00\xa2\xb7\xf1\xb9;\xc6\x91\x93\xa2@$~\xbc\xf0B'
        b'\x05\xebE\xf8\x1b\xde}C\xcbm\xe0&\x00\xcd5?\x00\xf4\x98\xceV\x87uKX5\x01\xdc\x95C\x8d\xaf\xa3\xcc\xbf\x9d\xa5v\xad3\xea,B\no\xa6\xc1\xcb|\xa8\xe3\xe4\xcd.\x1d\xa3\x86uei\xf2\x1f\xab@'
        b'\xc0J\xfb;\x03x>\x18\xca\x039\x07U0\xd4\xc3^"\x96\x92qs\xc5\xd9\xfa\x05\xb9\x9f\x05P\xa7\xd8\x82\xa7\xec\xcbc\x84\xb1`D\x1a\xbc~\xa8T\x875\x04s\x9d\xd9EI>5\x8c\xc1\xec\x9c9\xad\xbb\xd5'
        b'\xef\xb4\xf4\xdc"O\xf4<\x1d\xa7(\x0b\x08\x0c\xf8\x7fd\x87\'\xeb\xe3\xaa8\xd3~#`\xf4\xa6\xc9\xdfj\x8a8`\xd7\xe1\xb3\x05N\x18J\x0b7\xcf\xc0\x01\x03\x1b8\x1c[\x12\x11%J\xdc\xf3c\x00\xb7\xe89\x10'
        b'\x82\xaa(\xfa\xb2\xc0j\x17M\xd3{,\xb8\x87o\xf1\x1c\xfcK\xb2w\x9c\xf7\x01\x91=\xbfZ\x07\x8e\x18\xa6\xaf\x18I\x082\x0cc\xdd\xc9\xe0\xcc\xbe\xbf\rf\xfe\x91\xbdr\x0eS\xd2\xfd\x0e\xe66\xfd_\x11\xb5\x04\xd5'
        b"\xa9\xd5-\xc4\xf3G5\x86o\x05>\x95\x0e\xf3\xe7\xb9<\xc5r\xc5z#\x17\x8b\xb09\xd9\x8f(&\x13\xd1Q\xcd\xc1\x12\xb91\x90\xd8'4\xe4\x9e\xad\x0e\xfcI\xb3}\xb8\xbb\xc7_2JmT1wc\x12\x8e\xdb"
        b'\xae\xea\x18: \x87?\xe3f\xb1_\xba\x88d\xa8p\x86c\xfa\xc5\xb4B\xf9\xdf\x0eTfe\xa1B\xa1\xbfv@\xfd\x17u\xa9\xd2.\xb7dDsV\x93\xa8\xf6b\x0c\xdc\xde\xe4\xc2\xc26d\xcd\x8e\xe8w}\xe2\x08'
        b'pD\xc9HK\x15\xdb\xac(\xd5\xa5818\xce\x14w~p\x83\x9cE \x82d\xa72\x08n1+\xb8W>\x07\x14\xc8\x03\xcc\x17\x87\x8f\xd8%\xc9u\x12\xe7\xa5|\xfdZ\x08\xec\x10;\x8f\xe1\x01\x8f\xd8\xbb\xc2\x82'
        b"\xd0\xe4Z\x06)i\x14(\xc4\xb0\x0b\xb3\xaf(\n6'k\xd2b\x17\xdap\xe2\xf5Bc\x87\xae\x86H\xe2w`=u[dtX\x1ee\r\x81\xc8~\xe7\x9e\x95\x86\x02)\x9e\x1d\xb7\x93\xa8\x95\xe7)1l\xf8Z"
        b'[2\xdb\xa2\x82\x04b\x98\x98ai%\x1b4\xb2\xb5\xc2A\xde\xf7w\xea\x0e,\xb0\x95n"[\xb3\xd4!\xcc\x15m&\xc2\x94\xed7\xfbD\xed\t(\xed\x95&\xa7\xc8\xca7\x1b\xb6\xb5\xc2\x8a\x8f\xcc\x89/\x10-\xfc'
        b'\x11t\xaeB"r\x03]dU\xe4i\xddk\xf3\xd6\xc5\xe6E\xa8\xb7\xa8w:\xf9c\xff\x85\x14"\xe3\xf0}\xe5\xb8$9"\xbd\x9eW{\xdb\xeai\x12PGIO\x95[\x85\xcera7_5[\x15\xab\x8bt'
        b'\xa1\x1a?\xfd\xb2B\x1c\xdd\x87[-RRy\xfb\x17\x7f\xadcR\xafh\xe3\x16\xaf\xe83\xd0J\xbe{\xde{\xf9\x18\x12\xf0zf=l\xeb\x8e\xb6\x92e}~\xc8\xb9\xcd{\\\xef\x93\xfb"\x97\xd5\x81\x82\x93\x10\xb5'
        b'e\x11N<\x02\xe8\xd5\xc6e\xf19D\xf7\x14v\x95\x0e"A\x17\x84_iGb\xcer\x83\n\xfc< R:$j\x0e\x0bG\xads7@\xc5S\x8c\xa6\xd54\xc2\xe9\xd5Xa\xca\x1c\xc1\xceH}\x9f;\xd4C'
        b'\x17\xb9]&ix{\xc1\xb1!5`\x19\x980\xce|\xf3\xd6^\xaf\xae\x8a\xe6\xa9\xc3\xaad\x13/\x81E3]\x9d~\xd4\xbb0\x17[IV\xbeF\x9a)\x0cf\x8f\x97\xf0\xbe \x94a,\xbe\xbf\x95Xa\x96\x04'
        b'F\xab;\x7f\xb5?\x90\xdb(\x01\x06\xc6\x1e\x85\x95\xf2\x87CR\x193|\x1bG%\xf4\xa8\x17\xaePp0\xe4\xb7\xcc\x1b\xa1\xbf\xae\r\x1cL\xd6lr\x86>\x89\xac\x1e\x88\xde\xfb\xc8c\xd8\x8a_\xda\xad\xf9\xe5%f'
        b"\xe2\xfc\xc9\xb8\xee\x1e\x90G\x1a\x1d\xc2\x89\xa2P\x8fh\x03\xe4\x0bC\xfb\xf5\x05\xf1\x87\x17q\xd3!\xabD\xe3\xc5\x97\xc8\xeb,\xe0S\xce\xa1n\x82;7\xaa\xce\x93\xb9l~\x96\x18pWL\xfa\x936$o1'\xc1"
        b'\x9b\r\xb8v\x05E5\x89z\x8bKA\xaaP\xf9\xd8\x9c+\xdf\x85#C3\xcc\xae"\xd5\x8a\xd0y\xa7\xd1.\x9f\x9d\xc2\xc7\x1f\x83\xe3\x8d\xb0\xa3\xa2\xe22\x17\x1d\xc55Gm\xc4\x9d\xd8\xc3\x1d\xfc\xec;\xec\x92UY'
        b'\x84\x14\x1eY\xe9w\x86\x00\x13\x99\xacdR\x16\x83\x92?\xe8\x1e\x1e\x05>^?/\x96W\x0c\xddyj\x8cIQ\xe9\xda\xc3\xfe\xb9\x1e\xa6\x06\xe3\xec\xd3{\xe2e\x8a\xf7\xc68\xb9\xb5\x10\x17\xe2\xc3\xed\x1d\xf1\xa5\xa5\\'
        b"\xaa,j\xe5'\xefb\xa2\xf7\xd3\xee|:\xb0O\xd3\xfa\x83\xe7\x8aB\n/Bs\x87FV\x96:y)4G\x98\xc89\x9a\x99!\xdc\x1bY\x11\xbc\x08\xf6T\xf6\xde\x97\x82\xc1\xc11\xfa\x18\x9b0\xa8\x02\xdc\xc1J"
        b'Ub\xe3\xc8%\x10z/Y\x015\xe0\x88\xba\xb0\xffI<l@\x13\xcddM{\xb0\x0b}h\xfb0Mf\xfd\xf9|\xd7\x06\xcd\xda\x92\x99\xe33!\xa4|ysz\x0b\xd1Jn\xef\xd1\x19\xaf\xa0\xfd\xfaJ\xdd9'
        b'T.\xe0\xf8\x8fo\xfet4:\xab=\xf8\xcb0\xaf{\xbf\xcf\x85\xa4oO\x16U\x13=am\xab\xd9\xfa\x8c`TMt\xfa\xe6w3\x91{Gh8r|\xcf|!_\x8a\x1f`K\xb1%R;lg\xea\x86'
        b"\xd658\x02\xce`\xff\x1a(\x95)\xb6.\xb7K\xb0\x1cv\x00=\xd3\xcaJ\x01V<'\xa7M6\x1ez\x17+FD\xa4\xa8\x98\xbd\xc0\xedn\x05\xce\xabhZ4\x8c:\xcc\x8b\xf76\xc1\x99\x9bH\xb8\x83\xc2\xccn"
        b"x\x1bM3\xaa\xab\xdam,^\xa9g\xad4,*\xa0\xf6\xd0n=\x98\xe7IN#\x9f\xcb\xda\xecM\xe3'\x963j\xb7\x15\x8b\xe3(\x1c8\xdb\xbf\x82]\xe2/\xcc\xb9\xc1nP\xb4\xab0\xff\xf6\xfc\x93\x9d\xf4\xb9"
        b'\xd7\x02\x18\xe3;\xdcdl\x07E\x1d\x94\x9e\xb9\x80*\xbf4t>Z\x98a\xc9\x19\x9eD\x1cp\xe3\x13\xb8>\x85\x06\x16\x99\rv\x7f_\xfa\xb8\xcb\x9b\x92\xec\tD\xd0\x0b~\xae FN\x93\xbaKoW\xd1\x94\xac'
        b'\x87\n\xa7y\x13\xf0\xbeZ"?v\xd0~fM\x97\xf9\xc7Oj\xaf\xc3C\xa4t\xe4\x90\xcd\x83\xf0.)\x90\x0fI\x95@\xbe6\x83\xaa|R\x83\x1b\x1c\x11\xeen$6\xf2\x1b~\xe5\x11\xc5n\xc4\xf6\xb9\xd9\xf00'
        b'\r>\xb0\xb2\xdb\xb0\xb1\xa5\xde\x95P\xda:\xe0\xf4\xe3\x07\x91\x80\xc28\x9e$F\x98\x9dXW\x10\xb3\x8ej\xb3\xb0\xba\xbf\xdc\xa3\x86 \x0b\xdez\x9a<\xdd(\xf94\xee\xe6A\xb5XH\xea\xa8O\xaa\x83\x1c3\xb3\x05'
        b"\xa5\xce|f\xa7\xce\xa9\x1dX\x8f+\x8cP|\x0c\xa67\x0f\xbf\x1e\xd8z\x05<\xfe&\x97\xc9\x1b\x87'\x9a\x9eD\xd9\x80\xda\xa5\xe0>Vlr\x19e\xd6y\x9aF \x8b\x11\xec\x03\x91<\x84\xed\xf9[w\x15\xc2\x14"
        b'h\xdfG>\xdb\x1b\x8bz\xd5\xa4\xe1\xebJ_\xb2\x94(/<\x1e\xcb\x83\xf8\x11W\xa4\xaa\xffMk\xccd\n\xdbd\xd5\xf9\xbdKsz\xc9q\x92\x1c\xa95\x9f\xc2Z`%\x94b\x14\x8e>V\x1a#\x02\xf7\xda\xfe'
        b'\x01\x81E\xf5\xba\xb9l^F\xfa\xa9r4\x0e6GP34\xaa\x97\xa8:\xdd\xa2K\x86x\xd1\xf27\x1d\xc7oG\xfc\xdbi\tt?\xaa\xf4\xce\xcdS\xc5\xd2\x94~\xe9\xf6\xab\x05\\\xcd\xe4 Vc\xf5\x0f\xe6$'
        b'%\x10b\xd3\xcfho1\x13\xf3\x08A\xe3\x18Ja\xb9\x0b\xe0\x0e\x07\x90\'o\xfb\xf9\x1e\xc4\x83\xa4C\'\x9b\xf5\x94R\xad\x16\xe2p)\xf9\xb7\x9aO\xe3\xa5B\xed,P\x8a^\xa6\xfe\xa0\x00"\x86\x19\xaaR\x8a?'
        b'^\xe8\xad1\xb5\xack\xcbi\x08/\xf6\xe9\xbb\x19\xfc"e\x80E:\x87\xe2\xc6\xfc\xc8\x1dU\x14\x07\xa0\x9eCK\xc5$L-@\xcdv#\x8czd\xab\x85{``\xbb\xfb\xe5\xea\xc5\xbf\x1e\x0b\x98\x87\xb3"+\x84'
        b'\xec8\x99\xe3[\xd2\xc2\xc4d\x86\x07\xff\n\x94\xf5\x88\x96\xf6U\xcfJ\xc5\xec\xf4\x89\xe0-\xda\xadx\x0e\xbc\xeda\xaa\xe02\xa3\xbdS\x9f\xc3@\x93\xc6)\x00\x9a\xc8\x1a4\x84\xa0%\x90=[\x05o|\x8e\xbda\x9b'
        b"\xb3J\xe5\x0e\xf0\xcaT\xbe\x0e\x91\xcfId\xcb\xab\xe5\x9f'\x97\x85\xac\x84wt;\x8fzS\x11\xcc~a\xb8\xf4$\x9a\x1b\xf2\xb6\x97\xcf\xb0m][\x05\xc5\xa2O\xc24\xd9)\xbd\x97zu\xd1\xa3\x1a\xbe\xd5\xe5w"
        b'"\x01\xc2\xd9\xff\xf0\xe1\x8f\x9f\xbe)\x19\x7f\x04(L\x81y\xe05I\xd6\xed\xf0\xb0\xc1\n\x9af\xbd\xd0M\xb4O\\\xc1U\xcb\x1b\xd9\xe7M\x19\xbe\xc1\x95\xaf&f\x97\xfcg\xc2\xbc\x0cAE\xb2\xe3\xbaQ"\x83\x19'
        b'\xdc\xb7`\xc1\xb8>0SdM\xa2O\xd9\xf7\x1a\x1daJ-i#\xf4\x05\x88\x15\xfbI\xe6\x82\xe7n\x18h`5\xfdx\x92\xb4\x81\xcd\xd00n\x8dV\x80\x93\x1cU\xb2\x84\xdeg\x06\xd5\xd1_\x08\xd3\x10\xff\x9b\x19'
        b'\x99\xa5s\x82M.\xff\xa1\xcd!\xe3K\xb9\xe5\xfa\x06\x0e\xd0\x9f]\xd1\xa3\x95\x0f\xeb: \xe2\x95\x85\xdfc\x02\xb6!%  \x96!\x9e\x95d\xce\xb9!\x9c{_+\xa16K\xac3c\xe4\xe5\x9a#i(\x94\x1b'
        b'\xe3\xf8\x1f\xf5\xd5Lr\xc9\xc5\xba_y\xf0C\xb2%\xc7\xda\xaaQV\x93\xff\xc8W5\xdc+\x81x\xadTBl+\x97\x19h\xa3\x87Z\xb9`\xadR\xb2\x82\xad\xe7O\xc8c\xb4\x16(ptB\xb3r\x14H\xcc\xab'
        b'z\x1e\xc8L\xf6\xa7\xf2\xbb\xe8\xcaN\x0bw$o\x91\xa1\x99!\x8a`\xf3\x03\xd3\xcc\x80\xa4=\x04\xe9\x1d\xfc\x019\x85\x8c\x94e\xc0\x0f\xfa\x11(\xff\xc6\xbc$n\x93\xc3t"EP\xd3\x15\xac@w\xf5T\x1bb>'
        b'\xe4(\x84\xa1\xff\x1f\xcbR&9\x95\xfa\x98\x19\x91\x0b \x08\x9d9_\x88\x8eD\x85/m\xcc\x0c\x95J>\xab\xc8f\xe2h\x8a\x92U\xab\xb3L\x9c\x0bg?\x89\xe3}e\xf9\xe4\xdb\xe2i\xf4(g\xc4\x04\xf3Od'
        b'3\xc9\x8b&\x15\xe7\xb9-\xf7"\xf9>\x94\xcf\xf6\n\x1a\xcf\xdbF\xaa\xe3\xb7\x96\xd3\xb8?\x90\x1fa\xbd\x93\x105\xd1\x11{\xe0\xfc\xd5\x83\xf2!.\x9b\xb6\x91\xed\xa7\xf2\xc3\xe5\x9e\x8e\xb4\t\x8e\x92\x8d\x0e\xd8X\xfde'
        b'\xf3G8\x8cn\xcb}0\xc9\xe1.\xe2\xaa@Sp\xfaT\x0c\x81\xe0\xde\xe0~\xbfA\x15\x1db\x8f\xceYE\xce)\xe37e\xeb\xd6\xe3q\xdd\x8bF\xdd\nc\xa7 \x15\x8d\x01\xec\xb5hO\x8a\xb5\xc3\xf4\xe4f\xae'
        b'\xbf\xe0?\xf4\x1f|\xe6\xfd\xea\xf3\xc0/\xc7@_\xd9;x\x91\xe7\xd4\x1dbC\xb5b\x83\xf9\x99:\xbc\xe9YT\x909\xcc\xd9m>\x11\xd9\xa9\xd0w\xed\xce\x06J5D \xc4\x88\x00\x88\x0b\xee\\\rC\x8b\xd51'
        b'\x04\x7f\x95#\xad9\xd8 \xc0t\xf8v\xc0\xec\tx\t\xb0\xb9\xaf%\xff\x9b~\xe0\x91[\x8bXZ\x1f\x9c9\xd4\x8d\xc6\xe1\t\x03\xa99\x16y\x0ck\x0e\x86\x15\xda*s3l;M\xaa^\xddW\x7f\xc8\xe6\xe8\xe7'
        b'\x9c3t\x01\xfa\x85\xea\x8e\x0fA\x03\x0e|\x95a\xec\xc7E\xbcp\xae\xd2/\x14\xfb\x8d\xe7"\x0f\x96\xdd\xb7h\x9f\xf04\xb0,k\xed\xa6fG9i{\xa8\xc9\xbe/\x93\xeaG!J\xde\x1e5-q5\xa3/o'
        b'K\x19f\xa5|P\xe7*\xb7\xc2\x89d\xfe\xf8!\xb1\x86+\x8a\x98h\xf7R\x12\n2\x92\x97i\xb30\x19d\x8b\xea\x84\xf0\x95n\xfcG\xe4\x80\x1a\xf7\xb4\x8b\x8ew\xbe\x0b;\xfad\xe0*\xea\xa1B\x9c{j:F'
        b'\xdf\x84\x009Q\x167\xd6d\x0c-\x1c\x10\x1d\x0c(\xebc\xa1gAz\xd6\xa4\xd1\xfe\xba\xc5"^.P\x89*\xf3Yc:\x92\xb7>\xb27\xe5~\xa5\tu\x92\nq\xca\xf4:\xaeK\x0e\x85Dp\x8e\xd1\xc5\x1b'
        b'2\xc9\xeaBe\xcb.2\xf3\xb7aP\x11\xf7\xca\xc3\x05\xfd\xc2/\xb2\xec\xf3i\xb7u3\xcf\x14\xd8\xcb\'\xa2\xba\x04T"\xc6@\xfc\x16!(=\xc8\x9c.$\xb0@\x81>\x03Z\xa6Z\xf2\xea\x9f0\xe1#\x01\xb4'
        b'\xc2_>\xd0@:\xd5\xb4@\xa2\xf95\x86^\xd6\xf2\xc2\xeeH\x06\x0b\xf8\x83E\xc8X\xfa\xbc\xfe\x14\xef\x0e\'\x03\x7fh7\xd5xcw\xe4\xf3<\xef*\x86\xcdv\x8e\xaf\xfb\xca\x1a"\x129\xb4\xadS>Gi\x7f'
        b':\x9c\xf4\xe8\xb0\xb5\xc4\x1d#L\x8a=\xd8d\xd2\xc2\x15\x83\xddt\n\xdd\xfb\x9c\x81vt\xb7\xd2\x86\xc3\xfc@\x05;\xd6\xb2\xe4YOnD\xac \xfb\n\xee\xc9\xc5\xb8TO\x08r\x95h,-\xd2\xfe\xd6\xdd\x9d\xc1'
        b'\xdd\xa3\x17\xed\xab\xe8\x07\xbd\x00,\xe4\xc6\xa0v\xdc\x13\xe5V\x05\xdd\x10;\x86Jl\x118\xca\x7f\xe6m\x0e\xa1\xee:W\xf1\xc8K~\xe5\xdf\x13Bcf\xd6\x1c\x8a\x1cg\n\x8b\xce\x95|X\xc0\x1ff4\xfc5\\'
        b'\xe1a\t\xff\x19\xc3\xbe\x8b\xc6\xd9\xb5\xd2\xac\xb8\xf3\xc6\xf1\x9bu\xe4\x80U\xeb\x18\xbcX\x0c{\xaa\xfc[<j\x07\x15Y\x1d\x11\x156\xb9\xcb\x14\xf7\x9c\xb0\xff\x86j\xa81_\xbbf\xfb\x9c]D\x7f\xb8\x01\xa6o4'
        b'\xfc\xf2\x13q\xd1\xef*\xe3\xb6\x00a\n\xb6Z(F\x19s\x05\xe5\x15\xa8\x88J\x87+\xfa\xf8\xb3?\x1e\xde\xa3\xcf\xf4\xcf\xeey\x0b\x0b\x04\x02\xad@\x15\xb8\xd3\x10\x91#\xdb\xd6a\xcd\xa3!S\x95W\xd4\xa5(\xf7\xda'
        b'\xbc5\xdeg\x96\x1bL\x10\x1c\xd9\xb1P\x02F\x0c\xf5R|\xb0^\x9a\xae/ma\x01\xb8\x83H\xb4\xd9\x8do\x03\x8f\xc7\x19\xdan\xef\x19\xed\xa2a`\xc5\xc6\x07\x9e6\x90\x17\x02\xf9Z\x89\x90|N0\x00$\xb96'
        b'+\x05\x00\xd8\x19\xe62\x8f\xa8M-\x00\xc4\xcb\xa9^\xf6\x16\xdfUus\xb30\xd7\xdd~\xbe\x14\x9a\xdd\xd3\xbaEB\xd2:D\x89Lm\x1a\xb5\xb9\xce\xd4\x93+\xc9*\x1em-,\x18`\xaa\xe4\xdd\xa1\xdaT\x08p'
        b'\xe8\x8d\x96\xbb\xbd\x8b\x99\x89\xa6C\xfat\x0e\xbb\x9d\x08\xe7{\x8c\xd5[\x1d\xbdKs5\xcc\x1b\x87\x96ss,\xf8\xbf\x84\x90Q\xaa\x9ec&\x0f\x865\xf56\xac\xfa\x08\x05\xc5@T<\xf1W\xd4F>.\x1e\xe9Y'
        b'\xfe\x1b&B\xb2Hk\xf0\xa0\xd1\xc0EN>\x9e\x97Z\x98\xbc\xb1\xec2\xdb\xe3*\xd2\x85\xc9N%|\\\xf2\xfaE\xc3cxt\xbf\xe9\xb3t\xf3\xa0\x18\xe6=\xbd\x91\xfd\xdf\xc4\xfd\xd2\x19v3\xa1\xce\xe0N\x82q'
        b'~\xf77=\xcf7\x05\n^p\xc4Q\x8c8\x05u\x14w\xbf\xbb\\\xc9\xd0\xe6FO\xe7\x98\xdd\x84\xfe\xcb\x1d\xc6\xa2G\xdd\xdble\xf0k\xe41Q\x04\xbb\xa3\xc9\xab\xfc\x9c\xb0\x87\xfe\xa9\xb5/\x8eU\xb1c\xe7q'
        b'\xee\x88S\xf4"\r\x90\xe6\xd5\x16\xb5\x82\xb4\xd9\xfd\x87,\xafp\xd7N\xc1DwHI9\x15\xd9\xb1XL\xd7\xdaP\xb8\xd7\x15\x81*\x19\xc0/\xe0\xa0\x1d\x89\'\x8d\x15\xc48C\xa4;\x7f\x0f\xef-yV\x894L'
        b'\xa3`\xc5\xc7\xb8\x8d+o\xbf\x8d\xd7o\x8e\xce\xdf\xf7a\xcc\xed\xebpn\xe7\x8e\x13\xa0\xd9\x86\x99\xe8\xa3l\xd1\xc2 \xfa\xc6\xf9a5]x\\*u\xe3\xcc\x9a\xe7\xb3f\xe9h\x192R\x98\xaa\x16U\x9c\xff\x89_'
        b'\x1b\xfe\xc5\xc1\x02#DX\xb5p\xcb\xed\x87#f\x0c\x0eAHzV[:\xe0cU\xbe\xa6\x1c\x02\x81\xa3\xdc\x8c\x15\xd2MUaW\xc4g.\xeb\x9f\x11<@\xb5k\xee\xeb\x14\x00Ga\xbb\xcdYx\x8d\x80\xbf\x8b'
        b"t6V\x990(S\xfb\xa56\xef\x06\x17\x8bd\xc7\x8d\xed\x99\x04\x1b\xab!\x0e\xaa\xc9\xb4e6V\xee\x96\xbf\xaa\xea\xa3\xc8#\xd5\xd4\x160\x8b\x14\xd7]\x05\x85\x1b\xed(\xd1\x8b\x0b?\x1f\xeb=\xa1E\xd5G\xd1'"
        b'"\r\x81\xb6\xf5}K\xc0X\x83\x9b\x95\xd11\x11C\xbb\x98DD\xf9dlB?`\x8bn\x9f\xe5Lj&\xdf\xf7\x07\xeaNi\x94\x9a:\xc9e@\xa9\xa0}\x8c\x17\x97\xf1\x10\x11T\xd7\xc5\xfb*@\xc8\x07\xb6\xfe'
        b'\xac\x10\r\x0e\xb29\xef\xa3Dv\x8b\xaboO\x97n\xae\xeeW[\xbf{\x1c\xf3\x84S\xc42}\xa6\x1f\xcd\xcf\x8c\xd4\xe6\x80\xdb~\x90\xf96\t\xbfh\xbe\x8f\x99\x15\x98\x01\xb2v\xa4e\n?=#a\x07\xf8)\xf8'
        b'|Sl9]\xb8\'\xfaQQ\x83\t}\xe5\x02\x19\xb0j\xa0\nLX\xff[Dok\x950\xa5\xa2S\x98\x051\x12\x7f\xe2\x1feu\x0b\x93\xcfEGK\x80BI4\x8b\xfd\xb5\xf0E\x06"\x82\x06\xdem\x0bn'
        b'\xa4\xd6\xbf\\\x18U\xa9\xc8\r\xe5zg\xe4\xb32\x9a\xb9\xe7\xc1\x7fJ\x17\xe1\x0bY\x97\xfeIhv\xf6\xab76\xfa^\x84\xd3\xa6K\'\xc6OlF5\xb3\xd6r)\xcce\x1eK"\x86\xec\xc7\xb7\r\xfd\x15\xcf\x18'
        b'1-bH\x19\xdeA\xec\xf3\xa6\xf7\x17\xd9\xf5\xab \xf9 \xde\xbc\xa0\x1c\xcf\x001\xc3\xdc\x8f\xb4:|z\xb9\xdf\xf6\x19w-\xc6\xcf\xc8\xf0\xc9\xb7%\x1a\x87c\xe8\x18*"\x1a\xe0\xd9X?-0H\xb7N\xba\xcb'
        b'\x12\x82uE\x0f"\xac%\x98\x17\x9f\xb2\x0fA\xab\x99m"\x11\xff\x9bzY\x800\xd1z\x8a\xbb\xaa\xe0c\xec\xfc\xb8\xf8I!3iA\xfe\xc3O\x0f\x01j\xfc:F\x00\x8e\x9a\xfeT\x93\x9c\x04\x0b\xb6\x80x\xd4\xe6'
        b'\xff\xe5\xbe9\xb9\x08\xb8\x81\xe1\xf0\x06\xd3\x84\xb2\xb2\xc5\xd1a \xde,\x05\xf6u_Q\xef\xa7\xb2H][\xfa0\xfb\xfb\n\xd5\x1c\x94\xb0\xabb\xd5\xdbe#\x92\x9e\xf3\x91\x90\xa5\xa6\x8cGL\xeeo\x7fl4?\xa3'
        b't\x87\x80%c\xf2\xf7\xe4\xfd&N\x8c\nV\xfb\xc6S9\xc8\xc4O\x9a\xe5\xcbG\x98"\x18kD\xb6\xacxMC!\xe3\xc1\x04\x1c\x0c\xfby;\xb6\\\xc5\x04_\x8a\xcd\xb9T"\xe9>l\x15\xfa\xdfP\x86PU'
        b"\xa9\x17\x99\xe5\xa9\xd9:\xdb\x85\x92)}\xa9\xde\x1a\xd2G\xa2\x98\xfe91$b'L\xe0e\x058\x12\xd9\xa5M9\xb5\xbdPN\x0b\x85\x93\xda\x02\xb0\x85}n\xf4\xdb\x8f\x99\xcbP\x02Q\xd8\xf4\x175\xa1\xc5S\x1f"
        b'\x1b\x1a\xa30O\xa1\x87\xd0\xbe\x86_\x95\x9fA\xb3<\x04\x97\xe4\xb6\xe2\x9a\x94\xb7\xdez\xe2\xf2+\x86\xd8\xb6\xb7M\x83\x7f\xb6\xa3\x80\x08\x00C\xd5K3\x87\xd9M\xc6b\x19yo\xc3P\x02\x0c\xdcT\xa6t\xce\x1e~'
        b'%r\xa5)\xe2\x90\x93\xf4\x00M\xb9\x0c\xce\x04\xff\x1e\xdd\xff\xa1\xbc\xb6v\x0f\x0b\x84J\x91\xb9\xc3\x97\x1aC\x1d\x9c\x03\xb6\xb6\xb1?\xe6\x87)3\x87k8\xd6\xf4\x0e\x08\x08X\xa8\xbexb\x1c<\x13\x04Y\xc1\xc4\xbd'
        b"\x82+>n\xcb\xbc\x8f\xcb=\xedut\x01\xf74k\x0c\x85fAoz\xfb\x1e'\x8b$9\xf5\xbf\x85\xdf\xd7\x1a\x81q\xad\xa7H%\x07)\xb7s\xe20\x02O/\x1d\xf6\xb4}+\x03\x812\x0fn\xc6\xf2{UY"
        b'J F\xd1\x92P\xe4&\xe8^y\x90m\xbd\x95\xad\x86\x9c\x9fl\xe5\x11\xa4\x0c\xe2\xc3\x07((\x86\xf2\xe6\xb0\xa0^\x99s\x0b-H\xd6\xcd6\xe4\x1a\xd1<4\x87\xdf\x959IU\x1aG-\xe2c\xed\xd5\xe7\x92\x99'
        b'\x86G\xe1\xaas\x91\r\x99\x8b\xdck\xfd"\x1f\x14E\xc8\xb3\x8ct\xa4laF\x84\xeb\xec\x0c.o\xb79\x15\r\x17a\x93\x97\xa54\x0b\xb9.\x0f\xd2w!\xaa\x17\x8be4\xd3\xcf\xc5\njA\x15asDP-'
        b'\x99\xdb\xabl:\x15k\xbd\xdd\xfa\xf4\xd24\xa1\xfc\xac\xe0q\xc3\x91\x00B\xa8#\xc8\x99]a\x8e\x19\xf7P\xff\x97P\xfb\x01*U\xc1\r\x99.\xb0\x04r\x8bYfn\x10\xc2\x8e\xd5\x97f-&[\xce#(v\x10'
        b'O\xdcM\x03\xa7\x8f\x1cJ\xa9\x14\xb0\xe9\x01\x00\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__file'
        b'__\xa9\x00r\x05\x00\x00\x00r\x05\x00\x00\x00\xfa\x15<frozen fintech.iban>\xda\x08<module>\x01\x00\x00\x00s\x08\x00\x00\x00\x02\x00\x08\x01\x06\x00\x0e\x01'
    ))
