
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python Fintech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']

def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    ...


class SWIFTParserError(Exception):
    """SWIFT parser returned an error."""
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x0b\x00\x00\x00@\x00\x00\x00s0\x00\x00\x00y\x08e\x00\x01\x00W\x00n\x14\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01Y\x00n\x02X\x00e\x00e\x02e\x03d\x01'
        b'd\x02\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadeds\t/\x00\x00PYARMOR\x00\x00\x03\x06\x003\r\r\n\t4\xe0'
        b'\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\xc9.\x00\x00\x00\x00\x00\x00\xcb\xc8\xe4\xebl4\xf9\xee\xc5L\x9a\x96~\xac\x87\xf2\x00\x00\x00\x00\x00\x00\x00\x00\xe7\xfc\xe5\xc6c\x91\x87O\xb4\x1dmYg\xed\x90\x02V\xfcC'
        b"\x15Z,F\xdc\xcc~\xc2=eS\x8f\xd3\xf1\xee\x1d\xca6r\xeb\x0c\x824\x0c\x1d\xc3\xbc\xe2\x1fi\x83\xc1\xe6\x14\xcc\x95'\xf2\xb8X$\xd6\xb1\xf6A\xa8\xde\xa9\n\xf9:-wk\xf6\x9aD\xd5\x8f\x7f\xbd|\xb7\x82"
        b'"\xdfN\xc8\xd6B\xfdZ\xed\xa1.\xec2u\xed\xado\x05J\xe9?\xd9\\SfXw]\x07\x1d\xfc\xa0\x16\xdbZ\x151\xf6\xc2\x0c\x8d\xab\xa7\xa4\x00\xc7X+%\xaa\x8df\x03\xbcq}r\x1a$k\x03\xee\xf5\xbb'
        b'v\x81\x88\x91\x85<\x1bV\x92\xbc\xac\xc4\xcfob\x18\xde\xb9\xb0\xd60?v\xdf\xb0N\xfd\x04\xb7\x93\xf4\xd3\xf8\n?$\xc5\xce:\xa2\xc7%K@\x80\xe1\xe3\x95~\x0c\xb6\xc98Y\xf3{8$\xb2\\\x81,\xd0\x92'
        b"U\n\xc5=7\xe7\xdbY<2>vw\x82\xc3{\xd8}}4@\x03 Bg \x90z0'j>]\x14\xea\xfe\xb7d*k\xe4\xd7&\xd8\x9a\x08x\xd7\x83^\xb1\xcexB\xed\x97\xa1N\x8a\x18\x8d\x89_\x81"
        b'\x8fm\xc2\xbc\t\xd7\x17\rIu/\xa4CoZg\x80\xd9\x07\xca,A\xc4ij\xd0\xa4\xd9\xc3\xd5\x98\x81Y\xba\xe4V^\xef\xf8\xf9=;\xba\xcf\n(\x05\x01.?\xbeVm^X<\x082z\t\x81\xeeT^'
        b'~\xd2G\xddl\xcd\x18\x9b\x196\xee\xc7\xc0\xae\xe5?\xa7\xcfm\x93\xa6\x88j\x08l#\x03\xb7\xac\x8b>:\x03\xbd^\xe6+\xc3\xf5L\x14\xb5\x7f1\xf2g\x9f\xfc\xc3\xa0\x0b\xfb\x97\x9cbEAV`\x15\x7f\x9bt\x8c'
        b'm4\x03}\xc1\x07Am9\xfa\xb9\x85\xd8\n\x91\x9f\xcf>\x8b\x98\xc6\xc2\xe0\xbd7:c\x03N(`:\xa8A\x0c\xe6\xe16[\xcf\xe5\x01\x04-\x8b\x0f$G\x97V\x01\xfc\xdf.\xab\x16b8)z9\xe4\xfc.'
        b' 0\xf3\x0e\xd8\xb1y\xf7l\xd5\xcb/\xdf#\xed\x88\x98M\x9b1\xf8\xf5\x95\xba\xae\xad\xebG1y\x86\xab\xc8n\x05L\xb08\x05\xcf\xf2\x06\xb6\xb6\xd8\x19\xbdE*\x9e\xcd\xdaJ\xd3?\x08\xbc\xfd\x10\xae\x1b\xf45\xa6'
        b'\xf8\x0c\xde\x8b\x90\x9f\x01\x89\xd0\xdd\xf8\xbf^U:\xe6\xcecQM\x83\x8b$\xc4m\xeb\x0e\x9aZ\x1e\x872\xb5\x89\xc89\xb0\xeeW/\xa3\x9eqa\xfa=\xa6*\xe5SU\xd3\xa6l\xb3\xc3\xac\xb7\xf94\x8c\xb6\x8d\x82'
        b'\x9b\xbe\xb4(\xb2o\x96?\xe8\xec\x041\xb7I\xb2Jl;l\x85\xaa\xd7$\xc6\x1f\xab\x01w?\t(\xc1\x90\x9f\x81J\xbe\x96\xed\xfa\x86J\xb7B\xe3k\x0b\xd9\x92\x178"\xdeC\xe8\xf3\x10\xeb\xa0\xb5\xf2\x8d\xbf\x1b'
        b'\xc8\x1dN\xbe\no\xffV$W=\xbac\xf0\x02W\x96GIq5\x80"\xe8\x18\xc9\x1d\xf1\xa4\x01"`_\xd7\xc0\xc7&\xac"D\x13\x9b\xbb&\xcey\xf0+\x88\xac\xd4BJ\xad\x08\xa05\x95y2\x08\x8c\x07w'
        b'\xe8\x0cU7\n\xcb+\xa9\xc9\xca\xb37\x14\x8a\xc7H\x1cM\xc0\xc3\xd5(\x7f\x1en,\xaa0`\xd0\xc86\x8eC\xcb\xcf\xe1\xb6\xf4\x99gH\xa8\xa5\\O\x97A$\xc5\xb72\xde\xb2\xc9y\x81C\xb1]c\x8e\x1b\x81'
        b'$\xec6bi\xdcz74\xab\xa4LxTH\xfdN\x81\xb9\x07\x91\xb6\x8f\xf5L.\xef\xc4i\x1c\xbc\x06d\xcbm\xd9\x81[\xbf\xc6\x8a\x9f*:\x19K\xd1u\xf8\xf1\x91\xa6\x08\x9f\x11\x01U\x9dzy7\xf5e\x0f'
        b'\xc6\x0f\x0f\xa2Hc[\xd7\xablq\xe2\x1a\x81j\x11\xc3\xd6\xc6ti\xce4\x03\x05\xedD\x97\xb3\x8f\xd6\x81)\x134\xa6o\x8c\x84\x03:\xecfo.\x89\x86\xf7\xa0\t\x93S^\xa8\x0c.\xc6\xb0Y\xeb-\xfbe\n'
        b'\xed\x98.\xbb{j\xba\x94\xb8\xcd\xcd;\xb9\xb6\xe0\x7f\xc5o\xc6\xa3\x00\xd6\xd0Z\xe7\xae\x8e\t\x9f\x0c\xa3\x13v\xeb\xa08\xbe\xa9s\xb7&\xc9_\x0fS\x17\x13%\x7fs\x8f\x8bx$cH\xfa\x9c\xbc/h+\xa7\n'
        b'8z\xc8|Q\xba\xa3\xff\x10\xf6(\x15\\\xf0s\x9agzu\xabm}\xbb\x01\xe6\xf7\x81\x16I\xcc\'\x17\xb1g}\xcd\xc5"ks\xa4\xbco\xb4\x7f\x0e\x84\xce#\x1b\xe5\xfe\xb0s\x06Z\xd4\xd2\xdei9\x972\xa9'
        b"\xf8\xc0(095\x0b\xaa}\xa3:oG\xd5\x1b\xfd'\xa7@D\x02\xef\xa0\xf8xNp()\xda\xb1\xbeI\xe5\r\xe0i\xd5\xd7\xa4\x12\n\xbc!\xbd\x11^\xdal\xfb\xaar\x83b/z;%+W\xe9<\xb3\xd0"
        b'J\xa0\xc0h\xdb\xa4\x81D\x8d]n\xa8~\xe6$w+Y,+\xb8\xe1\xb3\xcc\x1b\x93WP\x0c\xb6\xea\xe6\x8fms\xdb\xe7\x0e\xf8k\xe6\x90PW\xb5Fs\x7f\xcb\x0c\xe6\x03\xea\x06\xd6\x03\x9b\xa6\x981_"\xafh'
        b'\xd5\xfb\xbc8\xf0\xaf\xe4\xb8\x89w\x06\xd3\xdc\xff\x82\xdd\xad\x90\xf4g\xb7\xdej\xe3\xcfI\x80\xc4\xd3H\xb7|^\xf2[\x1c\x04A\x9c:`\xbf\xa4\x9c\xaa\xa1\x83\xf5\xa4\xdcw\x9d\xfa1e\xf7\x19\x0f\x80\xa5\xe0\xf4@\xf5'
        b'\xf6\x0b\xf6\xa7\x7fj,\x91\x07\xc8\xf7\x950\xa3mNTv,k_\xf4_X\x99h1\xf8\tZ\xf7O\xed\xc0\xbcu@\xbcQa\xb0\xca\xb1\xd4\xb0ky\x8b\x02z\xb1\x19\xe8\x9f\x1bcP\xa4\xff\x94f\xed;\xaa'
        b'`\x1f\xf2j\xb7o\xf2\xc8G\xe2\xf1E\x0e}\xc6) @\x9fC}\xd7_b\x07\x9f\xf2\x024\xfe\x19k\xdc?\xef\xa1\xa4G~\x01@\xb2\xa2b&\xed\xa9\x06\xce\xa1\x9d\xbdx\xcb\xfc\xaf<E\xad\xb73\x89\xbf\xfb'
        b'\xeb\xdd\xe9.\xaf\xbc\x10\xd1\xd9\xe2\xe0Y>U\x0bP\xd2\xb8\xec,\xf7\xef\xb0\x1e)\xce\x87\xe9k\\\x13\xff\x7f\x80\xdae\xd9i\x02K\xc6\xa6\xd0\x7fFt\xa9,p\xf3*z\xb9\xb2%v\xf7\x16\xe7\rc\x06?\xe8'
        b'\x05\x9b\xd2\xf0\x8c\xd2s\x03(=\xff\xdd\xed\xf9\xa2r\xacrj\xa7U\x1f]\xe4\x05]L}\xf9\xdb\x0b\x9c\xbaK\x8b\xf1\xc8\xe3\xf0Ji\xf7D\x8c\x89QE.\xd5*\x15\x15m\xe2K\xd3\x0b\xe1\xf9\xac\xe3\x94\x07\xe8'
        b'U\xfc\xeb\x88\xd6}\x84\xbc\xaa\xc8\x15\xf7\x83\xb7\x94\xf5\x0c3\x0b\xb7e*G\x94>g{\xd8\x8a\x83\x18\xb2\xa4\xc3\xcbYGj\xbf\xd3\x89/\x88voa\xc0\xd8\xc6\x11\x0c\x16\x93q\xf4\x94\xa7P\xe7\xb7`/\x8cH'
        b'\xa5\x81\xa01\x9f\x1a\x16\xa5\xecb\xbd4\xf89<\xb4r\xea\xbc\x8f\xdf\x97eD\xe3\xcf_\x14\xc4O\xf2\x11\xdb\xcf{\xd6\x9d\xf8\xcf\x8e\xb9LW\x08-Y"Z&eD\xbb\x8d\x98\x10c\xe2\xdb\x1f\xd0c\x0c`0'
        b'lz\xad\xea\x9c\x9a\x18\xe6\xb7\x1f\xa0\xcb\x1e\x81U\xf8\xd9-m\x81j\xddh!j\xbe8\xfc\x0cp\x96\xb6\xc6$\xc1\x0cK\xbd]\x9f37b\xfa\xcf\x98\x81\xef\xde\xa0u\x13!!\xb3\x97NY\x87\xf0\xf6:\x99O'
        b'\xbf\x0b\x9a\xcad\xab2\xab\xc0\xd8\xedC\x8fK\x0f\x02,\x8b\xf5\xe82\xd7FJ\x95\xb6\xd1\xb6\xb2!\x99\xf5vNp\xb3\xb9\xcd\xa0]i,1\xaf\xebM\xb6_\xc4\x8eL\x1c\xecdG\x94\x05\xf5\x16\xec\xaa\x84\x99+'
        b'\xb3\x82\xe7v\xbd\xdb\\V\t\x17\x1e\x0e;\xbb\x13\x81r\x1a]T\xb6\x19"\xde\xa0\x01\xe1a\x14\x8c\xf0C\xc0\xe8t\xce\xe5f\xd0s\xebc\xd7\x19\xd8\xb0\x03\xab\xb4\xdam\xcfP\xa9w\xdfC\xa3,\x85\xb9\xa0\xc3\xb0'
        b"\xbfF<u\x04{\xcfOnu\x0b\x86\x0f\xecK\xb1$\xdd\xdf\xffva\x88u\xa5e@\xc0\x19>\x06\x8a\xa1\xc3\x9clg\xbe\x99'\xda+\xa4f\x004\x0e\x9c\xf0,\x81\x81\xfc\xb6\xcd=^\xbb\x13\x95\xed\xec(9"
        b'\xe0\xe3\x7fx\xcfg<W\xc1\xea\xb7\xd0wZC\xc39\xa9\xa9\x9baM\x88/\xb0\x98~\xf1\xf7\xb4%W\xbd\xef\xcf\xdf\xce\xb0\xa2\xc7\xc6\x14\x95\x10Y\xaa\xb8\xe0\xd8w\xd9\x9f\xf2C\xb2\x1e\xd1|\xe4\xe6w\x14\xd8\xa2'
        b"W\x02\xf7\xf99$\x85sK\x08\x0c\x9a\x00\x84\x0c(\xb9\xd5M\xc7G\x87_\xa0k\x0c\xfb\xb7rt'\xc1\xe4\xabQ_\x151'(`\xf4\xf2\xb3B\x15\x98\xf2/\x1fe\xa1\x9f\xe9\x94\x91\xac\xce\xdf\x01P\xaf\xef\xad"
        b'\xe7\x84Y\xf8\x82\x15u\xa7ptH\x87\xa2\xf8{H\xc6\xb7\x9bi\xbd#\xd8t\xf8UQCEy\xf9EB\xc0+\xbf\xfa\xec\xa4g\nB\x8fQ\xaf\x1a \xcf\xc5H\xef\x01?v\xab\x10\xe0\xb2e\x86\x82KO\xca'
        b'\x13\\\xaaFiLz\x16\xde\x8f\x8c!\x9aC\xeb\xeco\xaf\xe0C\x81a\xe2\rA0\x83\x86\xcb\xc3o\xea\xed\x12N\xf9/V\xf9\r\r\xe6\x00\xa81z*u\xe3\t6\r\x13W\xb3\xc0e3\xe9\xf5\xdfo\x9dk'
        b'\x9d\xeb\xca\xa0b\xea\xe2\xfam%\xf9\xb7@#\xd8\x12\x9d\xd9\x01X\xa2\xd8\x8fQ\xd2N\xd7{\xebF@\x0e\x14\xe663\xf9\x8c\t\xbeZ\xfb\xd8(vA\x0bu\x12\xe7W3\xda\x0c\xf1\xef\xf5\x00\xd5\x0c\x0f\xd9\x12\xd9'
        b'\xa22\x95\x0b\xf3\xdf\xfdW\xbc\xe35\xebN\x89\xc2\x07\xe1{=\xed\xbc\x0c\x0b\x82qH\xa1\xa0K\x0e\xaf\x7fQ\x82\xa3~>_\xec5h\x03\xa8\xa1\x8aS\xe0,\xdd\xd21tc%\x14\xef\xf3!\xd9\x0e\xe6\xf1\x16\x92'
        b'\x08\x91\xdaKRlq\xbe\xa9\x838\xa8R\xf5\x8a\x1dIv\x8b\xc5\xabTT\x87\xf4@\x8f\xb8I\xe6\x83\x93\xba\xf3\xef\x8c\x1f\x9a0P\xcb\x98@!9\xf1\xb9\xe6j*\x9f\xef\x11\xa6\x06\x9d+\x8a\x19\xa9,\x8b\xe4\x0c'
        b't(Z.\xbb\xd9\xf7\xafT\xfco\xfbQ\x16\xe1\xacJ\x08O\x1a4\x07v4\xa3\x07\t\xcf/\xd8T\x8e\x8ah\x87\xf25\x90\x87\x87\xe0z\x00\xae\xd8\xf8%\x1b\xbfr[\x81\xff<\\\xe2\x10:\x870rz*{'
        b'\xf88\x83K\x89\x16\xe4\xb8mCY \xea\xe0w7\xb9\xacw\xc9\xbd\xbb\xefXTL\xe9B\xb1\x84\xa8\xe8\x7fy\x1b+\xca\x85\x02\xf7\xd7\x10\xe0$\xc29\xef\n\xf4\xf4\xd2\xb6\x06\x13\xa9&M\xf2\xd2U\xa84w\xd4'
        b'\xa3\xf7\xa7@\xf3S\xdc\xff\xa4Y\x98\xcbO\x1d\x1c!\x82\xc0\xf7 \x1b\x9d\xe7^l_C\xe1e\xf1-T\xffS\x85\xdb\xbe"P\x16\x802\x8e7+R\xda\xf0\x82\xf0fJ/\x8f\x88\x1b\x99}Ppa\x95\xcd\xcd'
        b'<W\xea\x1d\xef\xfd*\x82\xe9f>u\xc3\x9d\xc3FpAT\xc3\x019v\xd3\xa5h\x94\xb8\x9f.T\x12\xd2)\xed)!\x90\xe9z9\xb8\xa5\x80+\x16\xd0h\xe9X~_\x9d\xdf\xdc\xd9\xaf\x88\xf6\xa4\xe7q\x8d\xd7'
        b'h)%\xfa\xd7\xce"u\xb8\xe0\x84\\B4\x0cn\xe8KM\xe4\x18g9y\xc3\xcc:\x1d\'\x15yX\xcc\x1f\xf8\x9d\xc1\x029FP\xc8\xb9f"\xbb\x13\xd3!\xc0\x08\x9fY\xc0\xd6E\x00\xcf\xc7e\xd9\x7f\xd6\xcb'
        b'\xad\xc2]\x9f\xc7\x12\xa6\xfd\xd5\xaa\xbe\xcf\xcf\xc4r7\xe9\'"O\x90\x00\xcfk\x80\xf7\x07a\x81\x15#/\xf7\x08\xa1#\xc4\xfb)\xddedfZ\xca{\xe1\xa6@\x927l\x14\x15\xd9u\xebY\xa0\xba\x15]#\x9f'
        b'\xd5\xfc\x9c\x95;.PRH\x1c+\xe4\xb4U4\xe0\xc3}\xcc\x95HB\xafy\x8dm\xbe\x160\x01\x86\x157\xd2\xdc.\xa8\x0f\xe5\xcd\xe5\xb5\xc7/n\xf5@l\xed\xa0\xdc\xc8W1/\xea\xd0\x9b\x0c`\xc2\x16\xba\x93'
        b"\xacnwa\x8b`\xa4/\xde\x06\xd7\xd9\xad\xe0\xb4W\xf4+D\xea\x90\xeacR\x8b\xb6'\xab\x9bM\xb2V\xfaA\x82\xe3j\xff{\xf9\x167-\x9fo\x89\x89\x8e\xe6v\xd7\xfc\x9d\x04V\xfe\xb6V7\xe0\xb9\x90\x89\xab"
        b'\x9c\xf5p\x84T\xab\xbfi.\r\xfe_)\xc2\xa4\'\xad\xdc,a\xb1\'\x10\x95_&\xdftL\x88\xfa\xfb\x97\xfa\x97\x0cUu\x11pl\\\x12\xb0\x00G"wFY\x1f7x\xf2:\xb5\x8e\xb6\x86V\xb0\xbf\xe0\x81'
        b's\xbe\xad\xec\xf1\x06h\xc3\xefMZkm\xd7\x94m\xc9\x91\xff\xe1\xc1.G>\xe8\xc8;b\x94\xfdD!\n\t\x1e\xa34\xcce\xdaD\xc7\x9f\x17\x8eK[.,[\x8c\xd7h\x95\xd9\x93\xef\xb7\xe0\xc4b\xdc\xb1\x9c'
        b'yd\xe2\x16\x11f\x9e1P~\xdc\xc0\x15\x19\xe5Z2k\xba\xfb\xa3q.\xf7Zl\x8ev\x04\xe2\xd6\xdc\x99\x86\xc3\xe8\xd0.\xdd\xafe\r\xc6\xcd\xb8\x04z\x9e!\x06\xa2\x06\x12~\xc4<\x0cU\x95\xf4A\xcb9\x1e'
        b']c\xe8\xaf&\xbc\x85ve\x0c\xca\x83\xf9w\xa1\x98\x0c\xb8\x12\x12\xa4\x01\x12<\xcc\xbd\xf1,\xa8\xe3\x08pSY\x1an\xc6\x14HO\x85\xa8\xe1T\xed\x08P\x91\xaf\xdceyv\x9c^\xc3\xef\xf5\xd2\x05\xbe\x89\xa1\xd4'
        b'\xef\xe9\xe7P\xe3d\xfd\x00Q\x0f\xc2\xb2\x87\xb0%\xa8\xea~\x87\xba\x1aK\xb7\xde\xce\x9d\xfe!\x8do\x064\x839\xc9\x85\xe2`\xfb^\x1eP\xdf\x904\xce\t\xcem~B\xd3\xd7\x00C\xdf\x1f\x0e#\x94\xdc\x9c\xf8\xca'
        b'\xcb\x1c\xa6&\xe4xP\x9bD7\xb7\x9a\x16\xfc\x0e\x94F\xc31\xd3\xa6\xae.\x9b\n\xf1|Q6\xf0\x11!j\xca\x92\xfe=\xd0\x05|v\xb0\xd5\xf4\x80\x0bru4\x13\xe6\xf3\xcc4^\x19\xb9\x04\x17\x02O)g\xcb'
        b'\xea\xa5\xc5Xe\x99\x03t\xd50\xb2:a\xfb&%\x9c\x7fD\x1b\xfa\xd5]\x93\xbf\xd0\x1e\xe9\xf4H\xeey\xc6\xb2-)\xb5mw6\xe0eV\x13\xdd\xe1_i\xf9\xf0a\xd2\xa6\x92\x06?\xc1\x97\xba,\xe1\xe3;X'
        b'\x84\x940\xefse\x15\x87fi\x01\xdaya\xa4\x8fRj\xd9\xf9\x0bVy\x83\x89\xe0U[\xfd\xec\xdb\xeb.\x01\xd1\xbc\x05\x19\xdaZ\xf8\x8e\xe3\xd5\x9b\x8e\x10T\xea\x0e\x9c\xde\xdeV\xc4`\xac\xaa\xf4\x13\x89J\r\xee'
        b"\xb3\x84o\xfa\xcfxp\xd0\xee\x11\xcc\xab'\xd5\xfb\xc9\xe6\x8crG\xff\xfdN\xbd*\x0e\x8e\xcb\xaf\x7f\xea@\x02O\xab\x8e\xd1\xa5>z\x9e7\x1a\xb3w\xea\x1f\xa7;\x9f\xee\xe6\xd5\x11\x02\xa0\x05l\x14\x12\xde\xe7\xefV"
        b'\xd1R\x18"\xea\xb0)\x9fH\xc4H\xc79\x01\x14\xad\xfa@\xae\x1fS\xc9\xc60\xf8S\xe2\x1a\xdb\x01\xb4\x98\xbf\xbd\x93\xb28\x988 1\xb23w\xac\x18>(\xbc\xcc\xff\'h8\xb2\x94\x01\x1b\x8a8:\n\xfco'
        b'\xec+\x17\x85B\xb5z\xe9,A\xfb\xc3\x14\xfd\x04#j\xde\xfdt\xc4IF \xa8\xd8\xc4\xf4\xee\xee\x95Yai\xcb\x89@\xfc\xe7\xc7W\x19(m\xd6\xc5\x0c\xb9~\x9f\xbe\x90\x1d\xe7yc\xe8\x0e\x04+\x8c\xd7\xeb\xc7'
        b'kP3K\xc1\x126[\xa0\xa7\xffRE+/\xaf\xb1 \x8b\x12\xf5"[B\xde\x04\x8e\xab\xeb\xf3:\xd2V l\xfd\x0f.\xf4\xf6\x11\xacT\x97&\xb1\x80\xb8\xe6"(\xe0.\xf9 \x83\xbe@z\x1b\xf9o\xf5T'
        b'\x02\x1c}\xfb\x7f$fU\xeev\xb2p\xf1X\x9ec$5\x06\x83\x82\xbe\xc8\xef\xe0\x0b\xccI\x94\xf3\xf8\xe8.\x0e\xfb\xfd!\x8ey\x0c6Y\xc6I\xee\x15a\xcd\xd8\xaa\x13S\xf4\xe25y\x19u\xca\xbc\xf1\xde*\x1a'
        b'g\xd6\xeezv\x83r\x84\xfe\xad\x9fw\x83\xf7<t\xa0\xad\xc1]>k\x0b_L\xf4\x98p\xfb\xf7\xc1m\x8b\x0c\xf9>`\xe2\x06\xf0\xcaT\x9c\x00z9tK\xf2\xd4k\x8d+\x00\xea\xd4I\tIP\xfa\x8b\x14\xf0'
        b'\xed\x9c\x81n\xbb7)H>\x97\x03\x11}\x97G\xd7dH\xa7\xce^\x8d\x12Z\xe0\xe6uC\xaf\x1f\xbd?X8\xb3\x92\xcd\xd1a\xb1\xcc\xe4\x83\xceu\x1bF\x97\xb7#\x99<\xf09\xd6\xde\xff\xd7\x00\x8e\xeb\xedmq'
        b'\xf4MF*\x1aWD\x0b\xac\x8c0J\x15\xf2\x06\xdb\x99\xbb\xd1c\x80s(\x9e9\'\xa9\xc9\x8d\xda\x876\xae\x9e6\xac\xc1l!\x05Y\x81\xd6e\x1e[\xfb\t\x10+$\x0cKQ]\xa3\x8b\xd6\xf8"\xee2h\xe2'
        b'\xa5\x13\x01\x96\xa8\xff\xc5\xf1\xc2*)\x17>y\x84\x98\xb4\xa0\xcc\x11P@\x0e>2*z@\xdd\xc5\x9b\xea\x061\xdfM\xd8\xcb\xe8 a\x82\x1a\xf4\x1f\xb4q\xb9\xcf\x13\t`\x9d\x9c\xf9uX8G\xc2\xe8\t\x89\xa3'
        b'\xcd\xeca\xade\xab\xee\xe8\xdc4\xd3\xafE\xcb\xe1\x99\xfc\x9c\x16>\xb0\xe6\xdb$\xc6\xbbW\xb3!\xf5\x98\xee6\'\xe5"\x0c\xb2\xd9o\x03t\xeen\xc3a*\x94\xf2\xbb\x1bN\x80\x1a?S\x96:\x85q\x13<0\xb6'
        b",\r\xf2Ma\xc9\x01\x06\xc1\xd2\xd7\xd9\xb0^\xed\x04\x11:{`*\xe5\xd7I\xab\xc6\xd4\x9bV\xfdxnX\x02IvhK^\xd7\x11\x1c\x84\xb4\xe2\xc9Q\x94\xe4\xa5;\xa8\x9e('<\xd2/\x08\x10\x97l\xd6H"
        b"\xe4\x03^\x99:l\x93\xf7\xfa\\5]/\xc0\xb5\nN#Q\x86w\x06\xdf\x99]\xa3|\x83\xb48K\xff\x18WdI\xc4^a,]f\x9b{I5_\x98'\x04\x97\x1a\xb8\x97mX\xc4t\xd6F\x9a\x86\t\x00"
        b'L\x9a\xd0\x8c\xc5\xfdt\x01\x15\xa6\xa1\xf2:\xfb\x01\x02dE\x12L:\xe1\rK/\x82 \xa9\xff\x8b\x90\xc7\re\x96\xed\xa6Z5\x00i$iLF\xf1\xef\x93\x9a\xdcg\x04 9\xe5q\x94T\xcd\xad\x03\xb7\xcb\xa9'
        b'\x18:\xdc\x95\xe7,\xb1\xae\x96\xe6)\xe7\xcaRW\xb2\xf0\x14\xfc\x92\xbd~\x83\xf0\x1c\x8c\xeanv6\x04w~\xfa\xff\xc2s\xbe<u\x89\x0fi\x98\x84\xab\x06$~\xd8\xe2Z\x17+\xcbS\xc0\xc2,\xd4\xa5\xfa\xa8I'
        b'\x01r\xd0B\xff_\xd8O\x8c\xf2L\x99\xd7r\x10\xe3\x94k\x87\x9aF-\xfe\xe9}\x9b\xc8\x96\xceI\xc5\x85\x06\xfa\xe6\xe8F\x96&\xaa\xf9\xd1\xf8\x17|\xf1I|R\xf4\xc0\x01\x03I\xcd\x87*smk\x94W\x88\xae'
        b'\xce%\x18\x04\x14\x9f\r\xd0\x83`\x0bxrGg\x13\x9ci\x07Q\xad\xfbD\x90\x80\xa3\xe1D\x88\xaaO0\x87\xaf\xc7\xab \xfb\x83D\xe1\xd70\xbb\xc3\xe7V\x0c\xe0\xfc3\xb9\xb9\xf0\xf3\x87\xb1\xc8nZs\xd8^\xc8'
        b'\xaa\x0c\x07\xbd\xdc\xb3Y\x12h\xc7\xa5\xe3/cC]\x16$\x99Cs\x82}A\xc8\xc2z\x930G\x0e\xea1\x05\x9c\xc1~S\xe4.\xba\x89\x01\xb1\xe6\x18\xb2\xec\xdakr\nGpI\xa6d\xb9\xe8z\x95xL`'
        b'\xe9n\x94{8\xd5L\x8d\xa9\xb2\xd3\x81\xf2\x90\xba\xd3\xf5\x80\xc4\x99\xb1+\x8cFE\xf2\xf9\x84V\xe1\xc5\xbc\x05\x93\xbb\x8e\xe1\xec{\x90\x0c\\\x07\xbc\xacn#,\x11\xa1\xc8\xa0\xa9\xd4sG\xdc\xbc\xef[\xc6@@\xfb'
        b'\x1cQ\xfb\xaeB\x83\xc5\xc0$a\xdf\x0b;\xcf@}\x7frT\xf74y-\xd8a\xe9~\xe90\x8e\xbe\xf4\xe6\xc9\xb9\xe5F\x9a;\x9b\n#\xa16\xbf\xcb\xaf\xf2\xee\xdc\x14\xdd\xf9\x85f(\xb2^\x90`\x9b}\x8aK'
        b'\xf6_\xd2\xc5B_\xf2\xfd\xdc\x99\xf1\xc8\xa1f\x90\xf8\xfa\x9a{\x04\xed\xeb\xb6\xf9V\x97\xc7h\x009\x01Hwp7\x96\x9ch\x84\xda\xfb\xfc\x08\x87\x93\xdce=\xacK\x19|"\xf40WN\xd4\xb1\x11u\xa5\xc3:'
        b'h\x84\xb7\xee\x0bu\xe1\xf1\x82\x8c?\x94\xebw\xa2e\x16V{)r\x94\xba \xb6\xab%\xff\x9f\x9e\xfa\xf0\r\xbep\xd6\x8a\x90\x93\x7f\xf5\xc4#:\xc4_\r\xe6u\xfd\x13Dh\xb9\xd7+\xcem\xa6\xe7\x1e\xdaDy'
        b'\xbe\xd5h]\xbdQYJ-\n*\x8f0\x8c\xe4\x0eZ\x11\x9ctOLJ\xd2B\x1b\x10a\xf5_^J>{\xb7\xb3\xb4\x11]V\x12H-U\x07vS\x90\xd2:\xca`\x8b7\x9b\xf4\xd1\x94\xa8lg\xdaz\xd9'
        b'\xcb\x13\xf0\x05\x199\xd5\xf6y\xddLm\xd4Jf7\xb1\x0f\xe0\xbc\x9e4\xe4\xc2\xe0\xcf6\tMT\xc8\x99/\xec\xf7m\x94[\xd4\xac,\x0c\xdb\x9e\x08tI.\x1a&\x19\xdeRE\xb5kyc1\x8d\xf1\xb7\xb9\xca'
        b'\xda\x03\x81>RYc\xe4\x80tj\xeb~\xb7\xd3\xc1\x88\xfa7\x1a!g\\\xda\x98\xab\x9fM\x1bo\x92\x9e\xc9{6\xa9z\xb9^o\xc8\x9e\'\xf6u\n\xb7\xff?0\xe3\x14\'R\xfc\r($\xfc\xd0\xab"\x18\x11'
        b'\xe0\xae\xf7\xf1\xb8\x92\xdb\xbf\xd6\xab\xb8\x9ag\xadw\xd1\x8c,\x94)\xfe\xcc7!\x8c\x19\xc2\xad\x9a\xfe\x01\xed\xba\x7f%W\xe3\x15\x8b\xed#ub\xdd`\x00\xa4*<\xa0z\xba\x91+j\xca8\xa1v\xd1Y\xd9\xe9\x8b'
        b'\x15-\xd3z{_\x82^\x91\x99S\xdc\x90\xea\x03\x18X\x1ce\x03\xb3L\x0f8NE4\xdeE\xa7\xc5\x84\x81h6\x9fY\x8a[[=\xb4|AR<\xb4i\xca\x9c\x93\x8a\x899\x93_\x1b\xfb<,\xc0@#h'
        b'\xbf\xdds\xabV\r=^\xf4\x8d\xf9\xf0s\xb0\x0cpP\xf0j\xdf&0\x9f\x03g4\xf9ju\xf35\x0f\xc13>\x11P6P`x,\xee\x88\x14u\xf5uB\xb9\x15\xc0\xff\xab6\xee?\xfa\xc8\x82ZH8\xf5'
        b'*^N\xf8\xe6\x00t\nk\xdf\x11\xe1w;\xab\x02\x8c\x1fhf~\x16\x14\x19\x1et\x99w\x04i\xb5\xd3\\)5\xaf\xbd\xa8\xf9\xb1u\x7fX\xa9\xe5\xbe\x10\x9a\x8fe\xd3\xf6\xb0\x1b\xf9ST\x9b\xe4WI\xde\x90`'
        b'W1\xdaN\x9a\xff\r\xa3& P\xd4\x9c\xf7#h\xe2a\x19}\x1c5\xef47>\xb4\x1aF%\xc5E\xdb\x93B.7{\xc4\xa4`\x16\xe0\xa7I\x11%J\xfaG\x1c\xb1\xf6S\x1b\nT\x1926\xb3L}\xf9'
        b'"\x86\xac=\x0fH\xc6\xfeP\x82}\xd6; \xefO\x9d\xd3Z\xba\x10\x9d\xc2\xb1\x1d7iK\xdc\xe2\x83\xe4\xc2+\xcf\x8a\xf9\xc3\xa8\x18M\xae\x9e\xa78(\xe2\xfe.N\x7f\xdf\xd5\x1a\x84\xf6\xd4\x16lH\xcaq\xaey'
        b'.\xe3;\xcc\xc2\xbfe\x183\xff\xc4\r\x1dc\x11\xad\x98\x04VgQ]6Q\xa3\x98v\xf6\x0c\x19\x1f/\n\xdc|"\xf7\xbf=\xb9\x8e\x85\xb3\x81\x99@\xca\xae\x8e\xba\x11KB\xa0\xfc,X\xdbatbz\xd7\xfa'
        b'\xdc\xf4L\x14\xf3\xcd\xa2\x99n\x84o\x05\xba\x1f\xab\xab\xf1\x92\x02\xa7\xd4291\xc9\xb1\xf3\n\xec\xa6B"\x959"\xc0DO\x88\x92\\SvN\x8e\x9b\xdf\x1a\x8b\xf69\x01\xff\xd6\\\xf0u\x0c\xdd\xcfC\xd9\xe4k'
        b'\t\xdb7\xe1\x0f\xcc\xef\x7f\xe0\xa9\xec\xe5a\xe1\xd0/\x9c\xf2C#!\x80\x1c\xf3P}0\x1b\x9f\xda\x87l\xbe\x8b\xc4T\x96\xf1%\xa2i\xfbB1\xb9\x94\xf3\x82\xe03\xafS\xc5 m\xa3\x0eJ\xba\x1b]\x91\x96\x8f'
        b'-j\xef\xde\xf9\x08L\xe5\xe4\x84\xcd4G>\xf77\x81s\x15\x83\xed0l&\x15\x83o\xda\xe7\xdf;`\xa9i\xb24Tk\xd6\xf0\xaaA\x0c\xbd\xcdk\xcc\xf6\xfb\xbd\xdb\xb2\xaa\xd2\xd9"\xb6c;:\xc0r\xb2\xa6'
        b'\xa2*\x8eFP\x88\x9c\x0f\r\xa1\xf3_\xe2\xeao\x82\xbcV\xe1\xd0\r\'\xc2\x89z$SV\xfd\xddG\x93Gu~\x90Y||\x8b\xb8\x1c7\xed{Q\x82\x86"n\xceR\xcah\xa0f\x1c\x84\x80\xff\xb8~[]'
        b'y\xa3\x95\xcb\xb4%\xc3\x1f\xd5/\xa9e\xb9f\xb88\xb1\x9f&\xf2\xb9\r\xb9\x9a\x88\xa0\x0b\xfb\xbd\xca\x1e%\xc3\xe2\xd5\x11$\x98\x82\xe2\xc3)\xca\xd6\x01\xac=\x9a\x01K\xc9\x00\xac\x86\xe1\x02/g\xc5p\x7fl%\xfe'
        b'\xfek8\x16d\xf3R\xda?\xd2\xff\xde\xcf\xe4\xba{lD\xf8kd\x8c\x9f\x08-(,-F/\xf1\x9ec\x14\t=\xb3\xd1tL\xae\xd2\x98\x89\x9d7\xa2y4\xcdn\x95\xe0=R\x91\xd7\xd1?]\xbe\x95\x7f='
        b'\xe8\x92\x13\x1b\x90\x88\xe4\xb4=\xa4\xbc\xe4#\x02l\x00$\xb2\xae]\x0e`\x8d\x983r\x1bh\x9bZr%\xd8\r\xd8\x10\xd2iB\x86\xf5\xed\xa5\xc9\x8e\xb8\x9fAYk\x14\xe3.\xca\x89\xde\x84\xf0YF\xf5\xfb\xa0\xea'
        b'?\x87_v\xd8\xb9\xbc\xdc\xa8\xd8\xf2\x1a\xba\x9e\xf7\xef^v\x97|\xce\xe77\xd7\xd4^\xd9y!\xd8\x90\n\x01\xa9U\xfd\xdeVxIsN%\x1c\xbeu\xc3O>^P\xa4\xba\xa7\xda\xdej\xde\xba\x81\x98\xb9F\x1d'
        b'\xf7v<X\xbb\xe2X\x98Z\xc5#\x18\xe1\x9e\xe7)su\xd0\xc6p){\xac\xe9.\x9b\x97B\xb2\x99\xd0Y\xb7G\xd1\x9a\xa0\x06)\x1c9\xd3\x90U\xf2\x9a \xe8\xe1\xc5}\xea\tD\xd6DuG\x1e(\xaa\xc6\xd4'
        b'\xd1\n\xe5S\x8c\xbd9\x9f\xa5\xe9v8R3\xd2kW.Z\x16u\xf0\xfa\x08\x92\xef\x92\x02\xff\x1eq2\xaa#\x8f\xb0_n{$\xd0#\xd4\x17\xfc\t\xa8\x935\x15\xb9 \xb9\xf2\xd8\xdeJu\x19N\xc1\xfd\x1e\xfb'
        b'\xc6e\x10\x86\x1a\xb94QB\x86)\x84\r\xe6\xf9\x15\x8b\x0c\x85\xefs\xf0\x9b9\x8f\xf0\xa7\x8d\xa8\x0f\x9ap\xc6\xca\xc6\x1a^\xbb%ox%\xca[\xe2~\x9fG\x7f\x93\xcfG\rD\x19\xfa(\x81$g\xb8\xd7\x12n'
        b'\xcc\xe0&\x1c\x1e\xd4\x9a*\xe7\xb3\x1c\x86y\x8b@H}lQ\x0f\r\x19\x8a\xe2\xe0V\xe4\x07I\xedVS\xf1?\xb9x\xc5\xdbJ3\x88\xd2\x8e\xc5\xbeO\xb4\x8b9 \xfdbq\xa5\xa7M\xe5z\xbaZ\x19\xbe\r\xe4'
        b"D\xb9}<\xbe\x8ca\x97\x1d\xd8\xfe\x8c\xe0\xac\xc6l\xca\xf8\x8f\xc560\xc2\xe1F\x9d\xc9\xe1\xd3F\x0f\xb9\x10\xc0\xfa\xfc'\xc2n\x9285V\xe3\xde9'\xc07\x08}\t>4\xc56\x9dM/Q\xcdr\xfc\x0c"
        b"5R\xc7\x1d\xa8(\xe5\xab/\x0f\xd9]\xb9\xc4'y\x97\xa2\xabQ\xeb.\xa8B\xc3VG\xfe8Q\xed5 \x10\xca\x14\xfc\r\x181s\x94fD\xdb\xf1\xa3\xb1\xa1\xd3\x0f\x121\xb1\x7f\x0b\xd6\x8d\xd7G\x13\xfb\x10\xac"
        b'/\xb2\xa3\xee\xc5\xd0i\x98\xefM\xa3\xdbmQ\xebM\xb9\xf8\x14tq\xe2\xd6\x17\xb7\xff\x8b\xec\xc3\xfdy\xf0\x17\xa9\x01"hS\x93\xa5\x9dHCk\xa9\xf2\xc7\x02}\xd8I\xa6\xa5c\x1e\xe1L\x11\x13`\xcd\xb0\xa9\xa6'
        b'(D9\x90\xabK\xc0\xd1\x90/c\x0f\x16y\x92GC\x98\xf7C\xf9\xee\xd1\x984v\x05.6;\x99\xcby\xf6`~\\\x88_\xf1\xd6x\xe0\xdc\xee2k\x15\xf66\xff\xaf)L\x95q \x99\x95\x95\x96\xa8\x14\x7f'
        b'\x1e5)\x16fR\x05\x1c\xb9y7\x1c\xea~\x96\xe6\x13\x9e\x99\xbf/X\x8fKL\xa3\xac\x81\x93\\\xbb\x05\xec\xb8RKj\xceO\xb6\xebX:\x03\xe5\xb5\xc4\xd1\x02\x8dWs\x8f\x81s\x08Ef\xc18\x12K\x11\xc4'
        b"I\xae\x96T\xe0\xe7d\x05\x8d>i\xc3\xea\x9a\niX<9\xce'\xca\xe6gF\x8f&\xdf\x9d\xda\x90\xa4\xf3\x90\xc1\xaej\x03\xbd,!2\x18\xd8\xe0Cr\x8d\xeb05\x99|\x97{\xaf\xdc\xc3|\xd6/)et"
        b'5j\xca-\xf2g`\xc8\x9d0\x133w\xb7H\xb4;P\xf4\tB\xb2}\xb2\xbd\xb3\xe3Df\xea\xf7\xefbt\x06\xdc\x06\x99<_\xf6\xab~l\xb31\xab\xe0\xf2\xbcW\x08j\x1f\x88\xcf\xaa\x92\x89\xcbF\xf9\xe2\xfb'
        b"\xad'\xdb\xef\\ah\t\xf3\x98\xef\x7f\xd0\xef'\x93y\x06\xea\xb2f+Vk5\xc0\x04\x10:\xf0\xd8\xe5\xf2\xd2\x96 (B\xe30\xb5W\xb9\x0c\xf3\xa6\xb5\x0e,\xd5\x83\x9e\xa5\xc4#\x02\xac\xe6\xb9{\x94\x8d\xbc\xd1"
        b'~\x1e\x92\x17\x81\x9aSJ\xb6J\xe8\xc9\xd6\x0b\xc4.\x02\xc0\x97ZvI\xfe\xbf\x19Z\xd9\xdc\xd5\xda\xf7 62\x96b\x0e\x1f\x9f\xdb\x1d!j\xdf\xfa\xd1\xa52A@\x02\xae\xac\xc2\xbe\x97\xe4\xefz%\x11\xbb\x06\xc5'
        b'\xb8\xcf\x95F\x84\x97E\x01\x02/\xbf;2\x81\xe7Hx\xd3\x1b|\x91$8\x02\xfb\xac\xf9K\xec\xe2\xa0,\x1b\xd0\x1f\xf6\xd8<U\xdb\xbc\xbb\xfe3\xcc\xc1\x14\xe8)\xbc\xd1\xf6\x8c\x8c\xbd\x14H\ta\xd8[\x9d ='
        b'`[\x99\x96\xcf\x173\xc1\xff\x17eV\x81\xa8\x7fx:\xe7\xf9)\xfeq@d\xd0\xd0_\xd1`w\xd5\xc9\xa0u~\xa2\xaa\xd82\xd9T\xedT\xdb\xd7\x17\xdc#\xe1\xa8\t\xbe\xbb\xcc\x02z{\x9b\x0c\x8d]\x08}\x7f'
        b'\x89\xd0J\xff\xda\x07.\x13d\xefA\xa4\xea\x0e\xcaW-\xc5k\xba8E;\\[\xd4W\x92\x1a\x03\xc0\xbc\xcd\xca\xfd=\xce^\x9ddl`J\x06x\xe6\xabN- \xa4\xd5N\x91\x99\x93\xd5\xf6\x80\xb6*p\x99\xf6'
        b'\xb3\x1dC\xf6\xa1\x13\x1dC\xf4\xeb\xa7\xa2#&\xbc\x156J\x9b\xfc)&\x18T\xf1\xb2"8>\xb5F\xadA\x918\x11\xbb\xdap\xce\x8b\xea\xf9\x0e\x15[\x84W\xa3\x97d\xf0\x11a\x93p\xa3/\xaa\xe4\xa7\x99h\xaf'
        b'\x87/U\xc2\xab<A\xd7#\xca\xb4\x0f#\xfcJW\x16\x07\x1e\x8e\x0f\x18\xcaFf\xef\xf0\x12\x9eO\xc1\xd3x8x\xc3\xdbH\xd7\xb1y9\x85\xb2\xfc\xcc\xb5\r\xe4\x06\xcc\x80\xf7\x89\xe4\x87\x8e\xb1\x82\xcf\x06\xf4z\x1d'
        b'\xe8\xaf\xa9\x05C\xfdS\xad\xb7^\xae\x89\xd6\xcc\x0e\x80\x8d\x83\xe4\x93\x9d\xac\xba-\x0b\xf0@\xcf\x1e\x98\xe9\xb5\xc0<\xd4\xe1G\xea\x060\r\xfb\xd3--\xfe\xcf\xb4\xc6^^R\xd2D!\xab\xe1\xd3\xcc\xaa\xe4P\xe6\x1b'
        b'lFd\xfa\x1b}\xdd\x88\xbb\xb5\xdc\xeeT\xcbd\xb4\xce\xd9\xa26\xc2\xdb\xf0\xeb\xc5\xa3\x0c[\xce\x9bE\xf9\x89\xa1\xcd\xf8\xd2\xba>&l\xcc\xe0\xc1p\xccP\xa4@\xa8\x06EO\x8d\x9b\xd8!kh=\xfc\x17\x0c8'
        b'\xa5\xfc\xf9\x10!\xf8\x18\x03\x94\xb5\x13!\xf7\x03\xe6\xdf\x96\x9aW\xad\xcdy\xb76Nor\x8e\xf1\xe5\xf0T \xaf\x86\xc5[\x9fri\xb7\xe6@\x1a\x0bV\xcaJzb\x13)\xcaM1\x94\xe7bXg\xd9N\x0e7'
        b'6\xb2\x10\xa9\xfd\xb1\xfc\\2\x10\xf6$\xf0\xea\x16-w\xa8\x1c\xb5r\xc5\xfb\xf6"S7\x1f!P\x8eG\xf1g\xfb\xb4\xbe\xbd\x8a\xa3uI\x9c\xd7I\xb1\xc3\x1e\xe2\xf3\xde\xb9j\x82 \xb3\xcfdSk\x84\xda\x06\xc9'
        b"\xf32x0;\xf0\xf7\x16\xcb=9\x0f\xd2\xeb\x91\x9csT\xad\x0e0\xf4<<\xab[\xdb\xe7\xe7_= 2\xe9\xcd\x01\xfa\xb7+^\t|\xach\xac'\x90Y\xecN\x9a\x01\x9a\xe7\xd4\xa3\xe6\xff\xe7\xe8\xf0\xab\xe8\xdf"
        b"2\xe6w~`\xe2\x07\xdcu\x83\xa3v\xfc\x92\x02\x87;;\xcb|\x89.M\x92i\xf7\xb0\x14\x8c\x7f\x1a\x97\xa6\xb8\xa9\xectMpLM\xaa\x90r\xd2\x15'\x91N;/\xfb&1\x92\x7f\x8c\x04\x0e\xd7\x06\xe1,\xed"
        b'\x80h\xa8\xe4o\xd4$\x12mP\x15\xc7\xa9\x1f\xe9-\xe8g\xa3\x9d\xb1q\xb8O\x1f[\x9b\xd4E\xc3\x9b\xd7\xa2\x8e\xe9\x87<\xe0v2u\xf8\xed\xe0Et9\x17~d\x952\x91\x7fUh\xc36\x07\x08w\x17\xcb\xbd'
        b"je\xeat\xfc\xbc\xb2\x1c\xdc\xa4q\x1c\xda\xf2\x95e\xee\xb2\xb8\xdb\xa7q9\xce\xdb\x19\x80E\xcf\x9fDV\xbc\xdfC\x1a'\xc1\x06(V\xe8/\xd6\x08\x13\x9e\xa9?\xe3\xdd\xc6\xb7G\xd5\x8d\xa1\x15\xc0k\x1d3\xc5\xd1"
        b'\xae\x98|\xfd\xc1\xbeI\xe4\x08\x88\x05\xfe\xcc\x9c\x0ee\xdf\xc1\x01\xc3\x98\xb2\xa5\xd2\x93\xf4\x8eB\x0c\xe51X\xe1\xbb\x9d\xba \xed\xe6\xdeFH\\\x00-5\xa3\x93\xe4\xb5N\xbad\x11\xb1t\xa8\x8f%WS\x9f\x10%'
        b'\x9fXQ\r#H\xa0\x00\xb3\xbdY\xfe"{\xa78\rb\xbaw\xe7\xbcmr[\xea\xffE8\xc1J^=\x1cz\xde\x9aDY<\x90\x9a\xec\xb9X#[m\xae1\xb8TX9P\xf4w\xdc},O\xdbT\x83'
        b'd\\\xc1\t\xb2\xa8\x997,\xdc\xff\xe0\xce\x85\xa0E\xc0\xa1\xf8&A\xab\xd2\xb5\xbe\x9a\xce\xe8\xcb\xc7\xce=o+n\xa0\xa2J\xca\xa16-\xd6h!\xec\x13w\x8d_\x8b@_\x1a\x8fp\x08\xe5\xac\x8b0\x0e\x13X'
        b'\x98\x17\xc4\x18\xbb\xee\x05\x91X\x80\x04\xd2\x17\xa0\xdf\x94\x82\xf8x\xd8\xf1\xc7\xa51\xdd\xce/x\xd9\x881\xaa\x07\xab6%O\xa7l\x02\x95.\x10\xeftcRl\xae#"Q\x95@[\xe5*m@\x02z\x16,S'
        b"<\xcf`p6\x16]\xf6\xb9*?k\xf4\xbb(\xe7\xef\xab\xbf\x0f\x07\xd9\xd4\x07\x0e\xd3\xe4\xa9\x15'\xd8dR=\xde\xcb\ti\r\xb2Qnf\xf3z\xa1K\xbe\xfaE\xb4\xb7\xa4\x8dF\xa6\x07\xd5P\x94\x88\x87\xe3\x98"
        b'\xd6\x0b%\x0e^HX6\x8c}\xa4\x94\xeb\xaae\x0c\x98\xe1\xc47|\xb4\xa2\x05) \x12\xc8\xbb\xdb\xcca\x1c\x13u\x8e\xec\xb1\x10\x8d\xe4&\x1e\xd96F\xa2j\xc8\xb2\x88\xbf.\xb7Q\x91\x1f[\xa0ye\x08\x14U'
        b'\xf3)Z\x8a\xa9o\xc6I\x9e\xca\xb6i\x96]\xc4\xc2\x84\x9d>2m\xe79\xa8\xab\x80\x89D(\xe4\xc7|\x18\xb48\xd1x\xf4\xfc\xe7Z%\xac\x03\x0b\x13\xee\xf97\xf2\x95\xc5\x1b\rk\xeb\xc9o\x0e\x80\x90\xfb\x00U'
        b'\xaf\xa7\xda\x9a\x08\xa2\x1a\x81\xcd\xfeq\x9c\xe6T\xc7\x7f\x05\x8c\x99T\x13z\xf4\xbe\x1f\x14\xb7\xdf\xc5\xf3\xc2\x02\xffVf\xe7C\x0f\x82\xf6\xb97U\x1f\xf3\xc3-\x06\x81\xee=L\x8e=\x1a{\xde\x99t\x9e\x17{\xd3V'
        b"\x00i\xd1\xe9\x0f\x84\xea\xa0\x94';4\xc2x\xdb\xafa\xcc\x8b\xeex\xdd\xe4\xe6\xfaJ\xd1+\xe7\x8bf+J\xfc7\x8d\t_\xba\xba\x8bWC\xb8\xdc\xfc\xbb\x9fI\xa7\xce\xd3<\x9b\xd7w\xd1\xf4\x84\xa2Q\xdb\xe9\x19"
        b'2>/@\x9b6\xbb\xcc\x14-\xe6\xa5\xe8\xad+k#\x00\x9f-\xecj#\x1a\x89\x1e\x10\x97@\xf4\xfe{\xe80:[>\xec{\xab\xed\xed\x97i\x8e0\xda\xae\xb9\xb8\xc70r\xbcgM\xa1\x1f(\xe6G#\x9f\x8c'
        b't\x12gK\xcb\x1f0,l,\x1d~\x89\xfd\x1f/h\xac\xad\xee\x89\xcb\xda\xa6|sF\x89#\xcd\x83\xefU\x9a.K\xd26\xa6\x08\xd6\xd2T?@\xae\x91\xa9\xb9\x19\xb1\x08\x89\xaf|\xd1?0\xd1\x97\xbc\xb7;\xf6'
        b"\xf6\x12o/eXtP^\xc6\x95c\x01\xac\x04\x10\xf8\xb0\x1d_\xd3\xbd\xb2Ma'\xee\x8d3\xfb\xd3\xf5\xde+\xee\xff\xdf\x0c\xe5\xa38\x17\x8f\x16\x9c\xcaw\x8d\xed\r6\xd7\n\xd6u{\x1e\xae\xd9w\xc9g\xd5\xdc"
        b'\xb4\xc22D\xa70\xb6\xeb\x08\xf7\x0e\x9d\xde\xa0\x05\xd8\xef\xa7W\xce`\xe8\x92\xfb\xdd\xb2\xd5%W+\xbc\x0f-\x86\xab;\xd5\xfe\xef\x95\xefx\xa4\xe9|\xda\x7f\x12k\xdb\xb6\xa8\xe8\xa6\x06e\xcf\xce\x83\x1e\xdb\xd5\xef\xbf'
        b'}\xcc\x07\xff\xc66\xaa$Fc\xf2\x98m\xc4S\xf5\xef$\x95.\xae\x10\xab\xba=\xc4\x188%\xe9A\xc0q\x0c]g\xcb\xee\x12\xab`\xbf\r\xcfU\xfd\x83\xeb\x8d\x9a\xce\x0c\xc2^3|\xdb\x04\x12\x17\xf1\xc4\xd1\x1d'
        b'\xdeT\xebGif\xf7\xeb&z@\xb6\xaa%\t\xe9\xf5\xf8R\xa7\xce-\xbba\x92D\x9cB\xf7\xb6\x82%\x10\x80\xf7q!\x08\x16Iz\xeb}Ot\xd9\x97tW\x0bV\x08.\xfd\x16\x86\xbbJ\xaeWU:\xaaO'
        b'\xea\xea\x1aTz\\\x1aA\xc5\x08)\x88--\xf7r\xbbZ\xacP\t\xaf<\x94<\x7f^w\xbe\x9b\x8bh\xff\x8cECI\xcbX\xb0\xd8\xa29\xc0\x1d\xe4C@\x82r*\xa3\x86\xab+\x15\xa7\x15\xff(1\xbd\x94t'
        b'\xb9\xf1\x16\xa4\x91\xf4-\xe1\xe0\xeaL\xed\x8eDK\x07\x91\xabq\xbe\x96\x8a\xaao\xec\xc5 F\x9e\xa3R-Z\xc0r\xf7h-\xd1\x8eBl*\xe2wQ\x98d\xcf\xbb\x95\x1e\x88\xdf\x8d\x82i\xd8\xfb\xda),\\k'
        b'`\x01\xcfa\x0bvI\xee\x08\x16\tdS\x9fY4\x01\x11m\x81\xb9\xa2m\xe4\xd1\x96\x9d\x17\\J\x8d\xe2\x96\x9dh\xdbdu\x89\xf9\xb6\x9c\xbf2e\x9d+\xa4\xcd\xc7^e\x06\xc4v#\xa6\xc4by\xad\xc7\xd9\x87'
        b'\x82\x81\xfd^&\xd3\n\xaa\x12\xde!\x86\xaf/;\xdc\x8f\xbfO\x908!\x7f\xbe\x16\xb0\xe2$QT\xa8\xe2\x83\x85\x91O\x12\xda\x96&\xc2w\xc4G\xbcM\x17\x99\x96<\xef\x9a\xb8\x82\xbem\xe8\xff\xbc\n*\xc1\x0c\xd1'
        b"f\xc4\x00\xf0\xd5\x92\xbc\xf9\xb4\x17\x97w\x86\t\xf2\x8f<\xc7\xc9\xc9c'9\x02\xf4\x17\x84\x83Q\xe9nl(@\xd2\x0c\x9b\xaf\\\x9d\xbbT\xc4\xe56\xf7\xac\x83'\xc0\xb2\x83\nL\x1f\xd9\x9c\xeey\x1b<\xfa\xf0E"
        b"\xa2\xd9c\x15\xf1\xda\xf3]\xd6Y~N\xe1\xba\xed\xc9['\xb3\xbe\x84\x8d\xcdO\x93Z\xd3B2\x19\xcf&C>\xdb\xd5)\xc1B\xb0+\xc2\xa40\xf2\xa0\x88|\xf0|\x94)\xa4%#G\x83\xbb\t\xf9\x9e\x8f\xca-"
        b'J~>\xfc\x8a\x07\xcd=\xaa\xa5\xd1\x9aU\x9diD\x1a\xf3\xc6\xff8\xeao\xf8fM8\xf2~+\xda\xf3\x84\x93\xb3\x89<\x1b\xf4;B\xf8e\xde\xd3\xefqx\xd3\x8c\xd5\x94\x01\x84ZfZ0\xa2V_Nl('
        b'\xb2x\x99:n\x17\x1b`\x80\xb3\xcdMDa\x90\xcb\xc0D\x84(.\xaf\xc9\xa8\xa1\xd7.\xc2\xcc\xdaC+@;%D@\xa3b\x144h>\x19\xeb\x96\x1bZ02w\xb6O\xd0\xecfiJ\x18\x16\x17\x1a\xc3y'
        b'\xec\xe5\x0e\xbc\xb4.\x85\x8c\xd3\xc3\xf6D\x14\x1e>\xd19\xdf\x87\x10\xb4\xfb\x8d\xc0\x89\xfb\xd1\x9f\xb9\x94\xfe*\xcfhQb,D\xef"1Sjg\xe5\xf7}\x99\r\n\x9ax\xba\x01|c\xde\x16\x94n\xb9\xff\x91('
        b'\x99\xb1<\xa7x\x82zA\x11AA\xd2p\xff\xd6\xb8\xf2\xef\x10\x9eO\x1c,k\xb5?\x9a\x84\xfa\xb1\xf3\xca(\x1a~\x9c\x02"\xe0\xc2Y\x85~I\'\x00\xcb\x81s~!\x86\xc8]~r\x0f\xd06\xa9\x1a\xaa\xbcA'
        b'M\xce\x15&:Lx\x12\xf87\xf8\x95\xdb\xa65@\x9b\x95\xc8\xdb\xa9\x94\x8d\xae\xc7\xbc9\xcd<\x92w\\\xce\xdd\xe2J\xff\x1f\xfem\x93e"I\xfe\x93\xfc\xf3\xb8\xd3\x10c\x11\x82\xd6\xb9Ys\x81>3;\xbe@'
        b'\xb8eV\xc72\xae\xd6\x85\xd4 \xb11!k\xae+\x12$q\xcd\xe9,\x88g\xcd\x970\xf4\xee\x0cv\x1b\x0e\x9e+mk\x97\xdf\xee\xe8S}ttC\x0fz\xe2q\xba\xb8\xf7\xc9\x92\xb0\xbfG\x89\x93P\n\xa0\xe8'
        b"\xd3\xdbJ'a\x11\x0b\xbc\xca\xa00N\x07\xc4\xa9\x8c&\xa8x\xce\xa1A\xd35\xc7O\xa0\xd1\xec\xecUb\xcaC\x0e\xfe\x8e\x9b\x84\xef\xa5\xf9\x00\xc8\xa7uW\x9b\x91\xc1c\xd1\xa3\xc0xr\x1f&UR&\x02;\xee"
        b'\xbfDY\x9aB\x1e|\xbd\xe7$\\\xbdI\xca\xf0\x08\x8eo%\xa3\x85X\x87#cN\xcc\xef-R\x82e\xf5\x0f\xac\x01\x16.\x9c\xf1&Zf8\xed\r\xd8\xe2\xc3\x91;\xee\xb9\x1e\x14\xdd\xb8A\xbfv\x12\xdb\xab\xf7'
        b'\x96\xa6\xff\x0e\x11\x04r\xee\xd9un]\x9f\x81\x98\xba\x88*\xd9C5\xa3\t$\x8fy?\x9f\xb2\x93\xee@{V!\xcf)L\xe30V\xfd-\x9f\x81=\x8f\xac\x0f\xb6\x96_\xc1x\xe6\xd5\xfcl\x0fJ\xda]\x14\xc7'
        b"\xb8G\x00T\xe8!\t@3>'\x06\xc7]nf\xb6\r\x87n\xe2\xa9\x07\xd3\xd3\xdf6{(H\x84`\x18\x12\x0f\xbe\x00\xd3\x10\xf3\xccv\x84i\xaaQ#U\x86\xed{\xa8\xa7],\xe9I\xc0.\xc2u&\x91\x06"
        b"j\xcf\x7fH\xe1\x92\xb0(I6\x833\xa7\xcdL\x88\xad6\x10\x04\x8b\x14\xe9s\xdaT\x9d\x84\xfb\xf6\xaa\xd1Y<\x81\xffm{\xcaC\xafV\x94ma6\x0c\x14\x14[\x939\x8e\xcf\xf3\xd3\xd7'\x7fE\xac\xd12\xbd"
        b'2\xcbp\xc4\xbeS\xda\x10\xd4\xc0\xc6Y\x0euw\xe9U\xc2\x11\xbd\x05\xad\x80\xc1\xc5!M\x82&\xcf\x13p\xaf\x7fI[\xed-Lh\xaf7\xf0D\x88\xfa\xa5\x931\xe1\x0e\xb8}$\x96\x7f&u\xcf\x9b\xfe\xcc\x80\xf0'
        b'\xda\x87\xee\xf2\x1f\x1d\xa3\xef\x90\xe3\xca\x053\xc1 \x17\xebe=\x99Z\xe6\x0f\xafm\xb7\xce\xefJ\xcc\xbb\xab\xb6M\xfb\xffN\x93CVV\xe7\xb8\xe5\r\x80pj\x8bj\xd0\xcf\xe4@\x87o\x82&\xbc\x93\xd7\xb2\xf2i'
        b"\xc1\xef:\xc9\x08M;af;\x05\xd5\xae\xeb\x99\xc1\xe7H\xbd\x94\xea'\x87\xe4\xb9\x9c\x82UCp\xb0\xc7\x8csBW\xff\xb89\x91[\xdb\x8f\x96\x88\x0b~i\x87M\\\xcf\xb7N1X\xd6\x06eE\xae\xf5\xad\xe3"
        b'\xbd\xea\xa7w\x19\r8\x08\xae\xcc\n_\xed\xce\xdc\xe7!\xbfs\x06\xe252\xdf^\xdfu\xf8\xd1\x11\xd4\xb9\\\xe7, b\xba\xea\xd8\xc6\xe7\x86X$T?\xf2hI\xde\xa1\x82:x\x8b\xa8\xc1\xbe\xf4\x83\xb65\xca'
        b'\t\xb4G\xddG\xf3\x9b\xdd\xc8\xdb\x0f\x15\x7f\x11\x81\x7f\x18\xf5=\x814\x84\xc4\xce\xe2\xb7LF.\x8e\x83h\x84B\xc2\x05\x9f\xc96\x96\xedxa\x9e\xf4\xa9\xb9D\x91x\xc2\x17L_\x8f\xd0\xc1aM\xcb]\xc8\xa0%'
        b"\xb3\x01\xf1\xa9\xc0\x87R\x8c\x04\xb2\xb3M\xe9\xb62\x85E\x82&\x10\x08\xb0\x02>d\xda\xcc\x83e\xa4\x82\xa4Ji\xa7d7@\x0e\xcar'7\x1d\xe2\x80E\xfc\xd05\xd0\x02B\x10\x0f\xae\xab\xfa\x14\x0f\xb6\x19@\x8a"
        b'8\x17\x83\x88\xc0_\xf2\xa4\xf5\xf7\xae\x8e{\x06\xb7k/\x14@\x81\x7f\xccl\xb7X\xa4B\x85$\xae\xc5\x9b1\x04\xa4\xb0T\x9f$2\xb4-[\xf8\xe1s\xd9\xe2n-{\xeb\x80\xbbr\x8c\x8d\x15\xbc\x02\xc13\xdeh'
        b'\x0e\xb8\x88O\x9d\xf5\xb1x?\xdf\x1f\xf3OI.Av\x11\xf6\xd3IIu-\xfd\xe6\x00\x05Y\xeb\xdd\x17\xa6\xe1\x85\x9a\x8f\xf6T\xb9\xd9\x86\xe3\xaa0\xf2\xe6\xe8O\xf8<B>\xf555\x12\x8c \x81\x19dN\xd9'
        b'\xe7\x98\xda\xb8\x8dxL/\xc3\xd0\xac\xd3v\x90-\xc9X!\xech\xfc8\xf2G+I\xcfBn\xdf\xb4b8\xed\xb0-\x8d\xb1\x84u\xe42\xa9Xl\xea\xb9\x93YB\xef\x1c\xd3\x0e8i\x00\xc5A8\xcc\xf1\xec\xd8'
        b"XI\x1a\xccI\x00'\x92\xb7%\xa5+m[Q\x18\x08P\xe89N\xb9\x17\xc25o\xc2S\xf52\xdf\r<\xec\xbfC&\\\xb3_Z\xd7\n\xf3}o|\xa3\xcdz\t\x02E?\xac\xe0\x12\x97N\xf9\x19\xf6TY"
        b'?\xc3\x9d\xd2\x10\xa9E\x91P\xf7\xb8\xff\xeaIZ\x0b\x0e\xe2\xfc\xbe\xd5\n\xc0\xc4\xc5\xa9#a\x92\xffvSn\xbc\xab\xd9\xed\x8a\xb2\xbe\x18\xc9d\t\x8e\x05\xde\x88\xf6\xe2\xe1\xec=9\xc2Y:k\x00\x98]\xb1\x96\xa0'
        b'r\xf0\xb9\xd9\xe0\xe8\x8b\x9do?\xfb\x17g\x87\x8a\xd3\xd1\xfa\xfa5\xc5\x8d\x8e\xbe\x13\x1b\x03u \xaf\xd0V8^><!\xe4G/wE\x9c\x93K\xfe_`Q\xbb6\x19\xaf\xf3Q\x8c\x81\x83v\x80\xb8\xc4 v'
        b'"\x89#\xdb\xce\xb1\x15\xec\xe8$\xf5$V\xbfF\x96!\xacG\xc5\xf8;B*\x19\x98\x08\xd0\x9d\xf7\xfe\xa1>\x00\x10\xd4\xb4\xe1\xc5\xfbB$\x14\x02G\x05Xg4t\xc8\xff9E\x13iz\xe1\x8c\x1f\xb1\xcbG\xcb'
        b"r\xb1'o?$\xa5\\a R$\x94\x9d\x9a\x98:\x17\x1d\xe6\x94dY\xae\xaa\x7f\xb4\x08'\xf0I\xb0)0E,\xa4\xf4:\xc0\\\xf4f\\\x15\xd49\x1b\xf7\xd1\x9c\xa0\x19\xfe\xe7~\xa7\xd2\x11\x13\xde\x90y "
        b'g\xe84\xb7P\xe5{\xb4\x9bv\xfbo\x82\x163\x13\x9e\x0b\xccE\xb6$Z\xfb\xd3\x0b~\xbd\xb3Eo\xb9\xacN\xe1\xfeA<@5;\x06\x92\x98&m-\xb4\xfc\xa3\x7f\xbfc\x81\x9c\xc0\xca\xf2\xadP,\xea\xe5\xc3'
        b'6+5\x95\x82\xc68?\xdf\xc2[\x9b\xbc\xc0\x82\xc19v\x94\xa6W\x05\x194^\x15s$\xabVo\x81}^\xa01\x8b\xa6\x96i\xe5\x08\xa33\x07v\x96\xf9!\xe3\xf8\x8b\x97@\xce0|f\xe8~\xb4\x98D\xfa'
        b'b*\xa1\x1c\x11-\x9c\x82\xac\xbf\xa7\x86)\x89\xf3\xc2a?m M\xcf\xd70\x83\x14p\xb5\x7f\xaf\x10\xb1)7\xe5\xa1@\xd4\xe8\rO\x98\x8du\x0fXpJ;\xf9\xad]\x97\xbd\xda\xa3\x93~\x07P\x06J-\xfd'
        b'\xdc\xff\xce\xebj\xac0\x00H\x13rs\x9c\xb9\xa6\xfaw\xdf\t<\x1f\x89\xd3;\x8cF\'\xb9\xec>sXW\x14"\x0c\x9d\x81\xf3s\xdb\xf1}\xab\xc7r\x8f\x0e\x0fx\x831Y\x93\x9b\xb0\x9b\x07\x86@\xd7\xf8k\xd2'
        b'\xca6\x0e\x98\xec\t\x0b\xb5\tKj&\x00C\xf2\xd3\x98\xeb4\xed\xb58d3\x93\x00\xb2 \xfd\xe7\x90\xde\xe5\x07\xb2\x83t\x88zv;/\xafM\xb5\xaaj}\x89zA\x0c\x14\x04\xec\xdb\xa6\xcc\xb1\t\tY\xc7\xea'
        b'j\xd6\xc6E\xdc9\x99\x9bX=\x11,\x99w\x9c\x95\x9e\xedE\xf0\xec\x81\xf5\xa4\xfc\x83B\xef\x11eb;\xd83_\xfb\x8b\xa2}\x14\xbc\xde\xb4\xfc\x1d)\x8e\x13\xfebYQ\x0f\x92\xa0\xf7\xc8i\x94\x97I\x90\xe5\xbb'
        b'\xdc\xb5\xb0^t\xb1X\xbbPW\x8e\x1f\x15\x86<\xfe\xe0\xcdF\x9a\xdb\x8b\xf2\xbc-\xe3\x19 "ia\x18\xe9\x1f\xb0"\xe8\xf5\x079]t\xf4\xd3s>^$\x02v\x9c\x10\xacO\xb6z\xe7\x9b\x1c\x1f\x07\x0e\xff\xdd'
        b'\x97\x95>\xb3\xaaw\xf3\xafc\x1e\xde\xdcVNWg\x92O2\x19\x1c\xeaF\x1d\x91\x87{e\x9e\xee\xb8\xf6\xe4\xfd\xd0\x0fX\xaa\xf4\xe6\xff\xf7@\xc6\x88J\xa2?kQGs\x9aM\xad\xfe\x91\xcer\x7f\xf1\xcbC\xec'
        b'M\x14P\x88\x13\x9a\xe4g\xfa"\x8e}P\x00\x17\x8f!\x10\x80\xb7\x81\xf5\xe7as{>\x12\x17R\xcc\x9e\x17\x99^V\x94kb3\x8a>\x1a\xa1\x14\xd8M@\xb4\x01G\xea\xd3\xa4{\\>\xe4c\x19\x02\x94\x7fg'
        b'\x156\x90\x97v\xca\xc1Pd\xbc$~\xee\x8d\xcaE[\x18\x12tc7\x01\xa7ikU`5GFM\xbe\x96\xc5&\xe4el\x9f\xf7\xe5[\x06\x8a_\xdb#*\xfd\xdcP+&\xacQ7\x88\x1f/\x1e\xb58\x82'
        b"\xdaf\xbe\x94\xa6\x94W5g\xe3(\t-\xa8\xd3\xd6j{\xf8\x1f\x07\x01p\xa0N\x0c\x80\x96\xbe\xa5\xa0\xdd2'j\xe8\xaf\xb6\x1c\xfe\x01\x15P\x8e<\x04\xb1qg9zH\x158+\x13\xc5\xcd\x1d\xe0\xb6\xe6'{"
        b']<.D\xfejlT#_}\x18\x8e{0\x03+`+V\x05\x84\xba\xbe\x19j\xd1\xf8\x14\x1a\x1c\x8fY\x86\xa3\xcb\xabk[\x84\xe0\xe6J&\xa9\x18a\x08\xc3\xfe\x0b\x01\xf9\xde\x8e\x07LZ&\x0f\xd7|\x97\xa3'
        b'\xf0\xd6\xcc\xb2:\x1a\xdc\xdd\xc4\xeb#gK\xa9c\xbd\x951\x80u\xfb\x885\xd2\x8d\xbf\x838\x90\xdf~\xee7\xef\x90\x9a\x07\xd7\xdc\xddU\x84\x06\x81=\xeb{x\xa3\xd7\xd9\xb4v\x13o\xc1SS\x01\xd7d\xbdB\x9e'
        b'\x90TC\x04C\xb5\xf9\xd7\xc61\xdc\x8e\xf1]X\xc2\xc3|\x17M`\xbfN\xc7\x11\x92\xad\xb6\xb7>\x14\x8a\r4\xa2\xaa\ne\x8e\xa1/I qL\x8d8\xb7\x06\xe8\xc1\xbbV\xdf\xe5\x06\xe5\xbe\x94\xf8\xef\x9e\xc5\xe5'
        b'9\xfe:c\x0cF\xe6\xfa\x1e\xf9\x02\xdc\xdfS\xefoi\xd6\x95\x9b,y/\xe4\x943\xfd\xa9\xcd\xe42\xb0T\xbc\xf7\x83\xb8C\x01[\xd2\xc8\xd0\x0f\xda2a\x95\xa9z$\x98}\x14\xa8Q\x8f\x1d\x14\x9d\x84\x8eS['
        b"\xd0\x84\\Sl\x80w#\xcb}X\xa4o\xbfhD X'\x0f *QobM\xae\x107\x87\x1et\xe2\xf4\xd4\x9f\xe0\xd9v\xb8}\xab\x1cs\x8b\x83\x9e7\xdb\x93\xb9\xeb\xb2\x03M\xc3Q\xb3\xf8/\xd4\x0b'6"
        b'_\x93\xe7\x97\xe8w\xa50\x82_kM\xbc\xee\xb0F\xe9\xd9\xbf\xee\x97r\xa34X\xdfz\x13\xcbJ\x1f6\x1e\xd9\xc1\x90\x8dCR\xc9\xad\x84\x12\x7f1@\xd8\xfe\x04\xb9\xed\xc7\x9a\xd3u2.\xacS(8L3O'
        b'\x08B\xe2\x05\x821\xb4s\x14\xe4\x08\xd8\xc1\xaa\x88\x996\xe71\x90C}\xc7B\xac\x03\xcb\xae}\xaaM\xfa\x01\xf4v}\x85\xe1\xbcB\xc9t\x90\xb9dv3\x7f1;s\xe0;\x03\x96\xe9\xbf!\x13\x1f\x8c\xd9Yz'
        b'\xe132\xe2\xb2]e\x90v]9_F\xba\xc23\x0c\xda\xa07\x13\xccf\x12{\xab\x00x\xfdv\xf6&\xb0\x96\xa9\x84\xef\x1a\x81{\x02Y\xa9\xc4\x0e<\x94\xe7\xff\x94.4\xd5g\xc7Q\xf1\x88\xd6\x9d\x07\xa1S@'
        b"\xea\x11\xbe\x84\xf4$\xbf\x91\x9ew\x8cxs\xd4f\x1dC\x8e3p\x14$\x02\xc8\xf4\xa0\x87\x0b\xfdr\x167\xc1\x80\xaf\x88\xcdL\xee\r\xe5'^l3\x9a\xa1\x8dC\xb0\x02\x10%\xea\x1ed\x8d\xb6\xcea\xa0\x95.9"
        b'\x18\xc4#j\xa6\xd1\xc5{R\xe0\xd8\xd1?\x13\xb48\x86\xfdX\xba\xc62\x14\x06\x85\xaf\r_n\xd8\xad\x83\x99\xc0\x83\xbc\xb2\xde\xa9\xd1\x86\x95\x1b\xbbf\x08\x04\xf1\xa2r\x94A\x11\xabr\x9d\x0cW\x1f\xcc\x8bB\x9b\xd7'
        b'\xe8(f\x9c\xc0\xe23\xeeb:\xd5\xb72\xe5IU\x90\x9di\xa4\xde?\xc0\xea\x0c\xd6\xfc\xcc\x89\xb3\xef\xec\xd6\x7fW \xa60f\xf2\x03\x1b\xd7\x9fa\x192\xea{\xf8\x94\x965\xf2%%\x96\xbb\xec?u\x8f\x9b\xef'
        b'\xdb+\x8b\x9d\x9a~rL\xcbD\x0e\xcaaM\x19\x08\xb6:\xb2\xdd\x8b\x88\xb2\xc95a\x0eg\x9e\xedp\xc7{Q\xbd\xbeX\xbbBU\xdc\xb1{\x8e\x87!@K\x8d\xbc\x14c\x89\x97\xe4\xfa4\xfc]#\x04Y}\xfd'
        b'\x98\x92\xcbi\xbfA\xfb\xfd\xee;\xe8\n\x16\x87\x04\xdfW\xbb\xcc`\xac\xb86\xc8TC\n8\xb2\xde\xbeHb7\n\xf5\xda\xb3\x82\x91\x94\xcb0\x12\xff\x16\x80\xb3\xa5n\xd8z\x7f\x8a\xe9\x01\x00\x00\x00N)\x04Z\x0b'
        b'__pyarmor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__file__\xa9\x00r\x05\x00\x00\x00r\x05\x00\x00\x00\xfa\x16<froz'
        b'en fintech.swift>\xda\x08<module>\x01\x00\x00\x00s\x08\x00\x00\x00\x02\x00\x08\x01\x06\x00\x0e\x01'
    ))
